@@ -89,7 +89,8 @@ import com.openexchange.guard.management.maintenance.internal.TestUserResult;
  */
 public class Guard extends AbstractRmiCLI<Void> {
 
-    private final char[] optionsWithArgs = { 't', 'e', 'n', 'u', 'j', 'w', 'o', 'x', 'g' };
+    private final char[] optionsWithArgs = { 't', 'e', 'n', 'u', 'j', 'w', 'o', 'x', 'g', 'c' };
+
 
     private static final String serviceURL = "service:jmx:rmi:///jndi/rmi://";
 
@@ -115,7 +116,7 @@ public class Guard extends AbstractRmiCLI<Void> {
 
     /**
      * Return true if ags includes action that requires authentication
-     * 
+     *
      * @param args
      * @return
      */
@@ -146,6 +147,8 @@ public class Guard extends AbstractRmiCLI<Void> {
     @Override
     protected void addOptions(Options options) {
         options.addOption("i", "init", false, "Initialise guard.");
+        options.addOption("c", "change-user", true, "Change a Guard user's email. \n   Change params --newEmail (new email)\nguard -c john@somehwere.com --newEmail johhny@somewhere.com ");
+        options.addOption(null, "newEmail", true, "New email address, used with change-user");
         options.addOption("d", "directory", true, "Full path of the 'oxguardpass' file (defaults to current directory). This flag should be used in conjunction with the '--init' switch.\ne.g. guard --init --directory /opt/open-xchange/etc");
         options.addOption("t", "test", true, "Test the specified e-mail address against the MailResolver\ne.g. guard --test john@somewhere.com");
         options.addOption("e", "reset", true, "Resets the specified e-mail address and sends a new password to the user\ne.g. guard --reset john@somewhere.com");
@@ -153,6 +156,7 @@ public class Guard extends AbstractRmiCLI<Void> {
         options.addOption("u", "upgrade", true, "Upgrades the specified guest account to an OX account\ne.g. guard --upgrade john@somewhere.com");
         options.addOption("D", "delete", true, "Deletes a specified Guard user");
         options.addOption("g", "guestreset", true, "Reset a Guest account.  Creates new keys for the user.  If has password recovery, must specify force to reset account.\ne.g. guard --g john@somewhere [-f]");
+        options.addOption("f", "force", false, "Force.  Used with guestreset");
         options.addOption("j", "jmx-user", true, "JMX user");
         options.addOption("w", "jmx-password", true, "JMX password");
         options.addOption("o", "jmx-port", true, "JMX port (default: '9999')");
@@ -208,6 +212,10 @@ public class Guard extends AbstractRmiCLI<Void> {
             } else if (cmd.hasOption('n')) {
                 String email = cmd.getOptionValue('n');
                 removePin(createProxy(jmxHost, jmxPort, jmxUser, jmxPassword), email);
+            } else if (cmd.hasOption('c')) {
+                String email = cmd.getOptionValue('c');
+                String newEmail = cmd.getOptionValue("newEmail");
+                changeUser(createProxy(jmxHost, jmxPort, jmxUser, jmxPassword), email, newEmail);
             } else if (cmd.hasOption('u')) {
                 String email = cmd.getOptionValue('u');
                 upgrade(createProxy(jmxHost, jmxPort, jmxUser, jmxPassword), email);
@@ -263,7 +271,7 @@ public class Guard extends AbstractRmiCLI<Void> {
     }
 
     private void resetGuest(GuardMaintenanceMBean proxy, String email, boolean force) throws MBeanException {
-        proxy.reset(email);
+        proxy.resetGuest(email, force);
         System.out.println(String.format("Guest (%s) has been reset.", email));
     }
 
@@ -275,6 +283,19 @@ public class Guard extends AbstractRmiCLI<Void> {
         System.out.println("Name: " + testResult.getDisplayName());
     }
 
+    private void changeUser(GuardMaintenanceMBean proxy, String email, String newEmail) throws MBeanException {
+        if (email == null) {
+            System.out.println("Identifying email address required.  Please enter with option -e");
+            return;
+        }
+        if (newEmail == null) {
+            System.out.println("No new parameters found.  Please enter new change.  -n for new email, -c for new context, or -i for new userid");
+            return;
+        }
+        proxy.changeUser(email, newEmail);
+        System.out.println("Done");
+    }
+
     /*
      * (non-Javadoc)
      *
