@@ -49,6 +49,7 @@
 
 package com.openexchange.guard.common.servlets.utils;
 
+import static com.openexchange.guard.common.util.JsonUtil.toJsonString;
 import java.io.IOException;
 import java.io.OutputStream;
 import java.nio.charset.Charset;
@@ -58,6 +59,7 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import com.google.gson.JsonElement;
 import com.openexchange.exception.OXException;
+import com.openexchange.guard.common.servlets.responses.CommonResponse;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 
 /**
@@ -80,12 +82,7 @@ public class ServletUtils {
         if (request.getHeader("X-Forwarded-For") != null) {
             return (request.getHeader("X-Forwarded-For"));
         }
-
-        if (request.getRemoteAddr().equals("127.0.0.1")) {
-            return null;
-        }
-
-        return (request.getRemoteAddr());
+        return request.getRemoteAddr();
     }
 
     /**
@@ -98,7 +95,7 @@ public class ServletUtils {
      */
     public static void sendResponse(HttpServletResponse response, int returnCode, String answer) throws IOException {
         response.setContentType("text/html; charset=UTF-8");
-        response.addHeader("Access-Control-Allow-Origin", "*");
+        // response.addHeader("Access-Control-Allow-Origin", "*");
         response.setStatus(returnCode);
         response.getWriter().print(answer);
     }
@@ -123,7 +120,7 @@ public class ServletUtils {
      */
     public static void sendOK(HttpServletResponse response, String type, byte[] answer) {
         response.setContentType(type);
-        response.addHeader("Access-Control-Allow-Origin", "*");
+        // response.addHeader("Access-Control-Allow-Origin", "*");
         response.setStatus(HttpServletResponse.SC_OK);
         try {
             OutputStream out = response.getOutputStream();
@@ -143,7 +140,7 @@ public class ServletUtils {
      */
     public static void sendHtmlOK(HttpServletResponse response, String answer) {
         response.setContentType("text/html; charset=UTF-8");
-        response.addHeader("Access-Control-Allow-Origin", "*");
+        // response.addHeader("Access-Control-Allow-Origin", "*");
         response.setStatus(HttpServletResponse.SC_OK);
         try {
             response.getWriter().print(answer);
@@ -160,7 +157,7 @@ public class ServletUtils {
      */
     public static void sendJsonOK(HttpServletResponse response, JsonElement json) {
         response.setStatus(HttpServletResponse.SC_OK);
-        sendJson(response,json);
+        sendJson(response, json);
     }
 
     /**
@@ -171,7 +168,7 @@ public class ServletUtils {
      */
     public static void sendJson(HttpServletResponse response, JsonElement json) {
         response.setContentType("application/json; charset=UTF-8");
-        response.addHeader("Access-Control-Allow-Origin", "*");
+        // response.addHeader("Access-Control-Allow-Origin", "*");
         try {
             response.getWriter().write(json.toString());
         } catch (IOException e) {
@@ -179,9 +176,20 @@ public class ServletUtils {
         }
     }
 
+    /**
+     * Sends an Object
+     *
+     * @param response The response
+     * @param responseObject The object to send
+     * @throws OXException
+     */
+    public static void sendObject(HttpServletResponse response, Object responseObject) throws OXException {
+        ServletUtils.sendOK(response, "application/json", toJsonString(new CommonResponse(responseObject)));
+    }
+
     public static void sendAnswer(HttpServletResponse response, int returnCode, String answer) throws IOException {
         response.setContentType("text/html; charset=UTF-8");
-        response.addHeader("Access-Control-Allow-Origin", "*");
+        // response.addHeader("Access-Control-Allow-Origin", "*");
         response.setStatus(returnCode);
         response.getWriter().print(answer);
     }
@@ -194,7 +202,7 @@ public class ServletUtils {
      */
     public static void sendNotAcceptable(HttpServletResponse response, String answer) {
         response.setContentType("text/html; charset=UTF-8");
-        response.addHeader("Access-Control-Allow-Origin", "*");
+        // response.addHeader("Access-Control-Allow-Origin", "*");
         response.setStatus(HttpServletResponse.SC_NOT_ACCEPTABLE);
         try {
             response.getWriter().print(answer);
@@ -211,7 +219,7 @@ public class ServletUtils {
      */
     public static void sendError(HttpServletResponse response, String answer) {
         response.setContentType("text/html; charset=UTF-8");
-        response.addHeader("Access-Control-Allow-Origin", "*");
+        // response.addHeader("Access-Control-Allow-Origin", "*");
         response.setStatus(HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
         try {
             response.getWriter().print(answer);
@@ -277,8 +285,7 @@ public class ServletUtils {
             if (mandatory) {
                 throw GuardCoreExceptionCodes.PARAMETER_MISSING.create(name);
             } else {
-                //TODO/FIXME:  Should return NULL with return-value type Integer
-                return 0;
+                return null;
             }
         }
         try {
@@ -301,8 +308,7 @@ public class ServletUtils {
         try {
             return (getIntParameter(request, name, false));
         } catch (OXException e) {
-            //TODO/FIXME:  Should return NULL with return-value type Integer
-            return 0;
+            return null;
         }
     }
 
