@@ -198,4 +198,17 @@ public interface GuardConfigurationService extends Reloadable {
      * @throws OXException
      */
     <T> T getServerConfiguration(String host, int userid, int cid, String configKey) throws OXException;
+
+	/**
+	 * Gets a string property only(!) from the "contextSet" scope
+	 * 
+	 * @param property     The property to get
+	 * @param userId       The ID of the user to get the property for
+	 * @param contextId    The CID of the user to tget the property for
+	 * @param defaultValue The default value to return if the property does not
+	 *                     exist
+	 * @return The String property
+	 * @throws OXException
+	 */
+	String getContextSetStringProperty(GuardProperty property, int userId, int contextId, String defaultValue) throws OXException;
 }
