@@ -74,6 +74,10 @@ public enum GuardProperty {
      * AES_Key_Length: 256
      */
     aesKeyLength(256),
+    /**
+     * Attach help file to outgoing emails
+     */
+    attachHelpFile(true),
     /**
      * Maximum lifetime of an authentication-token.
      */
@@ -122,6 +126,11 @@ public enum GuardProperty {
     defaultLanguage("en_US"),
     defaultAdvanced(false),
     demo(false),
+    /**
+     * Allow the user to choose to encrypt all incoming email
+     * This requires that the milter interface is set up.
+     */
+    enableEncryptIncoming(false),
     /**
      * The amount of hours specifying how long a deleted and exposed key will be
      * marked as "exposed", or 0 for disabling automatic reset of exposed keys.
@@ -186,6 +195,10 @@ public enum GuardProperty {
      * Specifies the SMTP username.
      */
     guestSMTPUsername,
+    /**
+     * Specifies email address to use in MAIL FROM
+     */
+    guestSMTPMailFrom(""),
     /**
      * Interval in seconds to check the RSA cache and re-populate if
      * less than 'rsacachecount'
@@ -214,6 +227,15 @@ public enum GuardProperty {
      * details here: http://oxpedia.org/wiki/index.php?title=AppSuite:GuardMailResolver
      */
     mailResolverUrl,
+    /**
+     * Address for the milter server to bind to
+     * '*' is bind all
+     */
+    milterBindAddress("*"),
+    /**
+     * Port for milter server to bind to
+     */
+    milterBindPort(8891),
     /**
      * Specifies the username for the basic HTTP authentication used for accessing the mail resolver.
      * If no username is specified here, com.openexchange.guard.restApiUsername will be used as fallback (default)
@@ -496,6 +518,10 @@ public enum GuardProperty {
      * Configures the AWS secret key to use. Required if storage type is set to "s3".
      */
     secretKey(GuardProperty.EMPTY, GuardProperty.PREFIX + "storage.s3."),
+    /**
+     * S3 Signer override
+     */
+    signerOverride(GuardProperty.EMPTY, GuardProperty.PREFIX + "storage.s3."),
     /**
      * Value of server version from Jva manifest
      */
