@@ -50,13 +50,14 @@
 package com.openexchange.guard.configuration.internal;
 
 import java.io.File;
-import java.util.HashMap;
-import java.util.Map;
 import java.util.Properties;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import com.openexchange.config.ConfigurationService;
+import com.openexchange.config.DefaultInterests;
+import com.openexchange.config.Interests;
 import com.openexchange.config.cascade.ComposedConfigProperty;
+import com.openexchange.config.cascade.ConfigProperty;
 import com.openexchange.config.cascade.ConfigView;
 import com.openexchange.config.cascade.ConfigViewFactory;
 import com.openexchange.exception.OXException;
@@ -100,21 +101,9 @@ public class GuardConfigurationServiceImpl implements GuardConfigurationService
         // no-op
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see com.openexchange.config.Reloadable#getConfigFileNames()
-     */
-    @Override
-    public Map<String, String[]> getConfigFileNames() {
-        Map<String, String[]> map = new HashMap<String, String[]>(1);
-        map.put("guard-core.properties", PROPERTIES);
-        return map;
-    }
-
     @Override
     public String getProperty(String property) {
-        return configurationService.getProperty(property);
+        return getServerProperty(property, String.class, null);
     }
 
     /*
@@ -124,10 +113,12 @@ public class GuardConfigurationServiceImpl implements GuardConfigurationService
      */
     @Override
     public String getProperty(GuardProperty property) {
-        return configurationService.getProperty(property.getFQPropertyName(), property.getDefaultValue(String.class));
+        return getServerProperty(property.getFQPropertyName(), String.class, property.getDefaultValue(String.class));
     }
 
-    /* (non-Javadoc)
+    /*
+     * (non-Javadoc)
+     *
      * @see com.openexchange.guard.configuration.GuardConfigurationService#getPropertyFromFile(java.lang.String, java.lang.String)
      */
     @Override
@@ -143,7 +134,7 @@ public class GuardConfigurationServiceImpl implements GuardConfigurationService
      */
     @Override
     public int getIntProperty(GuardProperty property) {
-        return configurationService.getIntProperty(property.getFQPropertyName(), property.getDefaultValue(Integer.class));
+        return getServerProperty(property.getFQPropertyName(), int.class, property.getDefaultValue(Integer.class));
     }
 
     /*
@@ -153,7 +144,7 @@ public class GuardConfigurationServiceImpl implements GuardConfigurationService
      */
     @Override
     public boolean getBooleanProperty(GuardProperty property) {
-        return configurationService.getBoolProperty(property.getFQPropertyName(), property.getDefaultValue(Boolean.class));
+        return getServerProperty(property.getFQPropertyName(), boolean.class, property.getDefaultValue(Boolean.class));
     }
 
     /*
@@ -193,7 +184,7 @@ public class GuardConfigurationServiceImpl implements GuardConfigurationService
      */
     @Override
     public String getProperty(String property, int userId, int contextId, String defaultValue) {
-        return getProperty(property, userId, contextId, String.class, defaultValue);
+        return getUserProperty(property, userId, contextId, String.class, defaultValue);
     }
 
     /*
@@ -203,7 +194,7 @@ public class GuardConfigurationServiceImpl implements GuardConfigurationService
      */
     @Override
     public int getIntProperty(String property, int userId, int contextId, int defaultValue) {
-        return getProperty(property, userId, contextId, int.class, defaultValue);
+        return getUserProperty(property, userId, contextId, int.class, defaultValue);
     }
 
     /*
@@ -213,7 +204,7 @@ public class GuardConfigurationServiceImpl implements GuardConfigurationService
      */
     @Override
     public boolean getBooleanProperty(String property, int userId, int contextId, boolean defaultValue) {
-        return getProperty(property, userId, contextId, boolean.class, defaultValue);
+        return getUserProperty(property, userId, contextId, boolean.class, defaultValue);
     }
 
     /*
@@ -235,20 +226,73 @@ public class GuardConfigurationServiceImpl implements GuardConfigurationService
     public File getPropertyDirectory(String propertyDirectory) {
         return configurationService.getDirectory(propertyDirectory);
     }
-    
+
     @Override
-    public <T> T getServerConfiguration(String host, String configKey) throws OXException{
-        return getServerConfiguration(host,0,0,configKey);
-    }
-    
-    @SuppressWarnings("unchecked")
-    @Override
-    public <T> T getServerConfiguration(String host, int userid, int cid, String configKey) throws OXException{
-        ServerConfigService serverConfig = Services.getService(ServerConfigService.class);
-        com.openexchange.serverconfig.ServerConfig config = serverConfig.getServerConfig(host, userid, cid);
-        return (T)config.asMap().get(configKey);
+    public <T> T getServerConfiguration(String host, String configKey) throws OXException {
+        return getServerConfiguration(host, 0, 0, configKey);
     }
 
+    @SuppressWarnings("unchecked")
+    @Override
+    public <T> T getServerConfiguration(String host, int userid, int cid, String configKey) throws OXException {
+        ServerConfigService serverConfig = Services.getService(ServerConfigService.class);
+        com.openexchange.serverconfig.ServerConfig config = serverConfig.getServerConfig(host, userid, cid);
+        return (T) config.asMap().get(configKey);
+    }
+
+    @Override
+	public String getContextSetStringProperty(GuardProperty property, int userId, int contextId, String defaultValue) throws OXException {
+    	return getContextSetProperty(property.getFQPropertyName(), userId, contextId, String.class, defaultValue);
+    }
+
+    /**
+     * Gets the value T of specified server property and coerce it to the specified type T
+     *
+     * @param property The name of the property
+     * @param coerceTo The type T to coerce the value of the property to
+     * @param defaultValue The default value to return if the given property is not defined.
+     * @return The value of the given property, or the default value if the property is not defined
+     */
+    private <T> T getServerProperty(String property, Class<T> coerceTo, T defaultValue) {
+        try {
+            ConfigViewFactory factory = Services.getService(ConfigViewFactory.class);
+            ConfigView view = factory.getView();
+            ComposedConfigProperty<T> p = view.property(property, coerceTo);
+            if (!p.isDefined()) {
+                return defaultValue;
+            }
+            return p.get();
+        } catch (OXException e) {
+            logger.error("Error getting '{}' property. Returning the default value of '{}'", property, defaultValue, e);
+        }
+        return defaultValue;
+    }
+
+    
+    private <T> T getContextSetProperty(String property, int userId, int contextId, Class<T> coerceTo, T defaultValue) {
+        if (contextId == 0) {
+            return defaultValue;
+        }
+        if (contextId < 0) {
+            contextId = -contextId;
+            userId = -1;
+        }
+        try {
+            ConfigViewFactory factory = Services.getService(ConfigViewFactory.class);
+            ConfigView view = factory.getView(userId, contextId);
+
+            ConfigProperty<T> p = view.property("contextSets", property, coerceTo);
+            if (!p.isDefined()) {
+                return defaultValue;
+            }
+
+            return p.get();
+        } catch (OXException e) {
+            logger.error("Error getting '{}' property for user '{}' in context '{}'. Returning the default value of '{}'", property, userId, contextId, defaultValue, e);
+        }
+        return defaultValue;
+
+    }
     /**
      * Get the value T of specified property for the specified user in the specified context and coerce it to the specified type T
      *
@@ -259,7 +303,7 @@ public class GuardConfigurationServiceImpl implements GuardConfigurationService
      * @return The value T of the property
      * @throws OXException
      */
-    private <T> T getProperty(String property, int userId, int contextId, Class<T> coerceTo, T defaultValue) {
+    private <T> T getUserProperty(String property, int userId, int contextId, Class<T> coerceTo, T defaultValue) {
         if (contextId == 0) {
             return defaultValue;
         }
@@ -283,4 +327,14 @@ public class GuardConfigurationServiceImpl implements GuardConfigurationService
         }
         return defaultValue;
     }
+
+    /*
+     * (non-Javadoc)
+     *
+     * @see com.openexchange.config.Reloadable#getInterests()
+     */
+    @Override
+    public Interests getInterests() {
+        return DefaultInterests.builder().propertiesOfInterest("com.openexchange.guard.*").configFileNames("guard-core.properties", "server.properties").build();
+    }
 }
