@@ -81,7 +81,7 @@ public class DNSServiceImpl implements DNSService {
 
     /**
      * Initializes a new {@link DNSServiceImpl}.
-     * 
+     *
      * @param validator A validator used for validating DNSSEC signatures of records, or null to not validate records
      */
     public DNSServiceImpl(DNSValidator validator) {
@@ -91,19 +91,20 @@ public class DNSServiceImpl implements DNSService {
     /**
      * Get a list of SRV Records for PGP Servers for given domain
      *
+     * @param serviceName
      * @param email
      * @return
      * @throws TextParseException
      */
     @Override
-    public List<SRVRecord> getSrvs(String email) throws OXException {
+    public List<SRVRecord> getSrvs(String serviceName, String email) throws OXException {
         List<SRVRecord> list = new ArrayList<SRVRecord>();
         if (!email.contains("@")) {
             return list;
         }
         String domain = email.substring(email.indexOf("@") + 1);
         try {
-            Lookup lookup = new Lookup("_hkp._tcp." + domain, Type.SRV);
+            Lookup lookup = new Lookup(serviceName + domain, Type.SRV);
             if (validator != null) {
                 //Decorating the resolver with decorators which...
                 lookup.setResolver(
