@@ -11,10 +11,10 @@ import com.openexchange.guard.email.storage.ogEmail.EmailStorage;
 import com.openexchange.guard.guestupgrade.GuestUpgradeService;
 import com.openexchange.guard.guestupgrade.exceptions.GuardGuestUpgraderExceptionCodes;
 import com.openexchange.guard.guestupgrade.osgi.Services;
-import com.openexchange.guard.keys.GuardKeyService;
-import com.openexchange.guard.keys.dao.GuardKeys;
-import com.openexchange.guard.keys.storage.KeyTableStorage;
-import com.openexchange.guard.keys.storage.PGPKeysStorage;
+import com.openexchange.guard.keymanagement.commons.GuardKeys;
+import com.openexchange.guard.keymanagement.services.GuardKeyService;
+import com.openexchange.guard.keymanagement.storage.KeyTableStorage;
+import com.openexchange.guard.keymanagement.storage.PGPKeysStorage;
 import com.openexchange.guard.oxapi.MailResolver;
 
 /**
@@ -32,7 +32,7 @@ public class GuestUpgradeServiceImpl implements GuestUpgradeService {
 
         //Getting key by email
         GuardKeyService keyService = Services.getService(GuardKeyService.class);
-        GuardKeys keys = keyService.getKeysFromEmail(email);
+        GuardKeys keys = keyService.getKeys(email);
         if (keys == null) {
             logger.error("Unable to find guest account " + email);
             throw GuardGuestUpgraderExceptionCodes.UNKNOWN_GUEST_ACCOUNT.create(email);
