@@ -64,9 +64,10 @@ import com.openexchange.guard.hkp.exception.HkpExceptionCodes;
 import com.openexchange.guard.hkp.osgi.Services;
 import com.openexchange.guard.hkp.servlets.HkpServlet;
 import com.openexchange.guard.hkp.utils.CheckWhitelist;
+import com.openexchange.guard.keymanagement.commons.RecipKey;
+import com.openexchange.guard.keymanagement.services.AccountCreationService;
+import com.openexchange.guard.keymanagement.services.RecipKeyService;
 import com.openexchange.guard.keys.PGPKeyService;
-import com.openexchange.guard.keys.PublicKeyService;
-import com.openexchange.guard.keys.dao.RecipKey;
 
 /**
  *
@@ -157,13 +158,15 @@ public class HKPIndex {
 
                     GuardConfigurationService guardConfigurationService = Services.getService(GuardConfigurationService.class);
                     String passwordFromAddress = guardConfigurationService.getProperty(GuardProperty.passwordFromAddress);
-                    String passwordFromName = guardConfigurationService.getProperty(GuardProperty.passwordFromName);
 
-                    //Check and see if we can get public key from the backend if member
-                    //This will create a key for a requested user if it is an OX user; but not a guest
-                    PublicKeyService publicKeyService = Services.getService(PublicKeyService.class);
-                    RecipKey key = publicKeyService.getPubKey(assertUnwantedCharacters(search), 0, 0, passwordFromAddress, true, true /* remote=true -> do not create guest accounts or query other HKP servers */, null, passwordFromName, null, -1, -1, "");
+                    //Check and see if we can get public key from the backend if member; No guest and no HKP lookup;
+                    RecipKeyService recipientKeyService = Services.getService(RecipKeyService.class);
+                    RecipKey key = recipientKeyService.getInternalRecipKey(assertUnwantedCharacters(search));
                     if (key != null) {
+                        //This will create a key for a requested user if it is an OX user; but not a guest
+                        if(key.isNewKey() && !key.isGuest()) {
+                            key = Services.getService(AccountCreationService.class).createUserFor(key);
+                        }
                         //Lookup the new created key
                         keyrings = pgpKeyService.getPublicKeyRing(assertUnwantedCharacters(search));
                         logger.debug("Sending list of keys, length = " + keyrings.size());
