@@ -102,7 +102,7 @@ public class HkpServlet extends HttpServlet {
                     response.setStatus(HttpServletResponse.SC_BAD_REQUEST);
             }
         } catch (OXException ex) {
-            if (ex.similarTo(GuardCoreExceptionCodes.PARAMETER_MISSING)) {
+            if (GuardCoreExceptionCodes.PARAMETER_MISSING.equals(ex)) {
                 logger.info("HKP request failed due to missing parameter");
                 ServletUtils.sendNotAcceptable(response, "Missing Parameter " + ex);
             }
