@@ -15,8 +15,8 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.hkpclient.osgi.Services;
-import com.openexchange.guard.keymanagement.commons.parsing.PGPPublicKeyRingFactory;
 import com.openexchange.guard.oxapi.pooling.HttpConnectionPoolService;
+import com.openexchange.pgp.keys.parsing.PGPPublicKeyRingFactory;
 
 /**
  *
@@ -30,6 +30,7 @@ public class HKPClient {
     private static final Logger LOG = LoggerFactory.getLogger(HKPClient.class);
 
     private final static String HKP = "hkp://";
+    private final static String HKPS = "hkps://";
     private final static String HTTP = "http://";
     private final static String HTTPS = "https://";
     private final static int HTTPS_DEFAULT_PORT = 443;
@@ -92,7 +93,12 @@ public class HKPClient {
      * @throws OXException
      */
     private String doRequest(String url) throws OXException {
-        url = url.replace(HKP, HTTP);
+        if(url.startsWith(HKP)) {
+            url = url.replace(HKP, HTTP);
+        }
+        else if(url.startsWith(HKPS)) {
+            url = url.replace(HKPS, HTTPS);
+        }
         HttpConnectionPoolService poolService = Services.getService(HttpConnectionPoolService.class);
         HttpClient httpClient = poolService.getClient();
         HttpGet getRequest = new HttpGet(url);
