@@ -78,6 +78,7 @@ import com.openexchange.guard.keymanagement.commons.GuardKeys;
 import com.openexchange.guard.keymanagement.commons.PGPKeys;
 import com.openexchange.guard.keymanagement.commons.exceptions.KeysExceptionCodes;
 import com.openexchange.guard.keymanagement.commons.util.PGPUtil;
+import com.openexchange.guard.keymanagement.commons.util.UserIDCreator;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.keymanagement.services.GuardMasterKeyService;
 import com.openexchange.guard.keymanagement.services.KeyRecoveryService;
@@ -88,6 +89,7 @@ import com.openexchange.guard.keymanagement.storage.KeyTableStorage;
 import com.openexchange.guard.keymanagement.storage.PGPKeysStorage;
 import com.openexchange.guard.user.GuardCapabilities;
 import com.openexchange.guard.user.GuardUserService;
+import com.openexchange.pgp.keys.tools.PGPKeysUtil;
 import com.openexchange.tools.encoding.Base64;
 
 /**
@@ -557,7 +559,7 @@ public class GuardKeyServiceImpl implements GuardKeyService {
     @Override
     public void addUserId(GuardKeys key, String newUserId, String password) throws OXException {
         key = Objects.requireNonNull(key, "key must not be null");
-        PGPSecretKey signingSecretKey = PGPUtil.getSigningKey(key.getPGPSecretKeyRing());
+        PGPSecretKey signingSecretKey = PGPKeysUtil.getSigningKey(key.getPGPSecretKeyRing());
 
         //Getting the private key used for singing
         PGPPrivateKey signingPrivateKey = null;
@@ -569,8 +571,8 @@ public class GuardKeyServiceImpl implements GuardKeyService {
 
         //Adding the user id to the public key ring
         PGPPublicKeyRing modifiedKeyRing = null;
-        try {
-            modifiedKeyRing = PGPUtil.addUID(key.getPGPPublicKeyRing(), signingPrivateKey, newUserId);
+        try {            
+            modifiedKeyRing = UserIDCreator.addUID(key.getPGPPublicKeyRing(), signingPrivateKey, newUserId);
         } catch (PGPException e) {
             KeysExceptionCodes.PGP_ERROR.create(e, e.getMessage());
         }
@@ -597,7 +599,7 @@ public class GuardKeyServiceImpl implements GuardKeyService {
 
         PGPPublicKeyRing modifiedKeyRing = null;
         try {
-            modifiedKeyRing = PGPUtil.revokeKey(privateKey, key.getPGPPublicKeyRing(), revocationReason.toString());
+            modifiedKeyRing = PGPKeysUtil.revokeKey(privateKey, key.getPGPPublicKeyRing(), revocationReason.toString());
         } catch (PGPException e) {
             KeysExceptionCodes.PGP_ERROR.create(e, e.getMessage());
         }
