@@ -22,7 +22,6 @@ import com.openexchange.guard.exceptions.GuardAuthExceptionCodes;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.keymanagement.commons.GuardKeys;
 import com.openexchange.guard.keymanagement.commons.exceptions.KeysExceptionCodes;
-import com.openexchange.guard.keymanagement.commons.util.PGPUtil;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.keymanagement.services.KeyRecoveryService;
 import com.openexchange.guard.keymanagement.services.PasswordChangeService;
@@ -30,6 +29,7 @@ import com.openexchange.guard.keymanagement.services.impl.exceptions.GuardCrypto
 import com.openexchange.guard.keymanagement.services.impl.exceptions.GuardChangePasswordExceptionCodes;
 import com.openexchange.guard.keymanagement.services.impl.osgi.Services;
 import com.openexchange.guard.session.GuardSessionService;
+import com.openexchange.pgp.keys.tools.PGPKeysUtil;
 
 public class PasswordChangeServiceImpl implements PasswordChangeService {
 
@@ -65,7 +65,7 @@ public class PasswordChangeServiceImpl implements PasswordChangeService {
         if (oldpass == null || oldpass.equals("")) {
             keys = changeTemporaryPassword(userid, cid, newpass);
         } else {
-            keys = changePassword(oldpass.trim(), newpass, keys);
+            keys = changePassword(oldpass, newpass, keys);
         }
         if (keys == null) {
             LOG.info("Bad password for change");
@@ -92,7 +92,7 @@ public class PasswordChangeServiceImpl implements PasswordChangeService {
                     keyService.storeQuestion(userid, cid, question, answer);
                 }
             } else {
-                if (oldQuestion == null) {
+                if (oldQuestion == null || ((answer != null) && (answer.length() > 1))) {
                     keyService.storeQuestion(userid, cid, question, answer);
                 }
             }
@@ -159,7 +159,7 @@ public class PasswordChangeServiceImpl implements PasswordChangeService {
         newpass = CipherUtil.getSHA(newpass, oldKey.getSalt());
         PGPSecretKeyRing keyring = oldKey.getPGPSecretKeyRing();
         try {
-            PGPSecretKeyRing newkeyring = PGPUtil.duplicateSecretKeyRing(keyring, oldpass, newpass, getPGPEncryptedData());
+            PGPSecretKeyRing newkeyring = PGPKeysUtil.duplicateSecretKeyRing(keyring, oldpass, newpass, getPGPEncryptedData());
             if (newkeyring == null) {
                 return null;
             }
@@ -192,7 +192,7 @@ public class PasswordChangeServiceImpl implements PasswordChangeService {
         newPass = CipherUtil.getSHA(newPass, oldKey.getSalt());
         PGPSecretKeyRing keyring = oldKey.getPGPSecretKeyRing();
         try {
-            PGPSecretKeyRing newkeyring = PGPUtil.duplicateSecretKeyRing(keyring, oldPassHash, newPass, getPGPEncryptedData());
+            PGPSecretKeyRing newkeyring = PGPKeysUtil.duplicateSecretKeyRing(keyring, oldPassHash, newPass, getPGPEncryptedData());
             if (newkeyring == null) {
                 LOG.error("Failed to change password");
                 throw KeysExceptionCodes.NO_KEY_ERROR.create(oldKey.getEmail());
