@@ -470,6 +470,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
                 stmt.setString(15, key.getSettings().toString());
             }
             stmt.setBoolean(16, key.isCurrent());
+            stmt.setString(17, key.getMisc());
 
             stmt.executeUpdate();
         } catch (SQLException e) {
@@ -503,6 +504,26 @@ public class KeyTableStorageImpl implements KeyTableStorage {
         }
     }
 
+    @Override
+    public void updateEmailAddress(GuardKeys key, String newEmail) throws OXException {
+
+        GuardDatabaseService guardDatabaseService = Services.getService(GuardDatabaseService.class);
+        GuardConnectionWrapper connectionWrapper = guardDatabaseService.getWritable(0, key.getContextid(), 0);
+
+        PreparedStatement stmt = null;
+        try {
+            stmt = connectionWrapper.getConnection().prepareStatement(KeyTableSql.UPDATE_EMAIL_ADDRESS);
+            stmt.setString(1, newEmail);
+            stmt.setString(2, key.getEmail());
+
+            stmt.executeUpdate();
+        } catch (SQLException e) {
+            throw GuardKeyTableStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+        } finally {
+            DBUtils.closeSQLStuff(stmt);
+            guardDatabaseService.backWritable(connectionWrapper);
+        }
+    }
     @Override
     public void updatePublicAndPrivateKey(GuardKeys key) throws OXException {
         GuardDatabaseService guardDatabaseService = Services.getService(GuardDatabaseService.class);
@@ -556,6 +577,8 @@ public class KeyTableStorageImpl implements KeyTableStorage {
         }
     }
 
+
+
     @Override
     public void updatePin(int userId, int contextId, String newPin) throws OXException {
         GuardDatabaseService guardDatabaseService = Services.getService(GuardDatabaseService.class);
@@ -651,6 +674,29 @@ public class KeyTableStorageImpl implements KeyTableStorage {
         }
     }
 
+    @Override
+    public void updateMisc(GuardKeys key, String misc) throws OXException {
+        GuardDatabaseService guardDatabaseService = Services.getService(GuardDatabaseService.class);
+
+        GuardConnectionWrapper connectionWrapper = guardDatabaseService.getWritable(key.getUserid(), key.getContextid(), 0);
+
+        PreparedStatement stmt = null;
+        try {
+            stmt = connectionWrapper.getConnection().prepareStatement(KeyTableSql.UPDATE_MISC_STMT);
+            stmt.setString(1, misc);
+            stmt.setInt(2, key.getContextid());
+            stmt.setInt(3, key.getUserid());
+            stmt.setLong(4, key.getKeyid());
+
+            stmt.executeUpdate();
+        } catch (SQLException e) {
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getMessage());
+        } finally {
+            DBUtils.closeSQLStuff(stmt);
+            guardDatabaseService.backWritable(connectionWrapper);
+        }
+    }
+
     @Override
     public void updateSettingsForUser(int userId, int contextId, String settings) throws OXException {
         GuardDatabaseService guardDatabaseService = Services.getService(GuardDatabaseService.class);
@@ -673,6 +719,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
         }
     }
 
+
     @Override
     public void setCurrentKey(GuardKeys key) throws OXException {
         GuardDatabaseService guardDatabaseService = Services.getService(GuardDatabaseService.class);
