@@ -90,6 +90,7 @@ import com.openexchange.guard.keymanagement.commons.GuardKeys;
 import com.openexchange.guard.keymanagement.commons.OGPGPKey;
 import com.openexchange.guard.keymanagement.commons.PGPKeys;
 import com.openexchange.guard.keymanagement.commons.util.PGPUtil;
+import com.openexchange.guard.keymanagement.commons.util.UserIDCreator;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.keymanagement.storage.KeyTableStorage;
 import com.openexchange.guard.keymanagement.storage.OGPGPKeysStorage;
@@ -98,6 +99,7 @@ import com.openexchange.guard.keys.PGPKeyService;
 import com.openexchange.guard.keys.dao.KeySignatureVerificationResult;
 import com.openexchange.guard.keys.internal.pgp.exceptions.PGPKeyExceptionCodes;
 import com.openexchange.guard.keys.osgi.Services;
+import com.openexchange.pgp.keys.tools.PGPKeysUtil;
 
 /**
  * {@link PGPKeyServiceImpl}
@@ -198,7 +200,7 @@ public class PGPKeyServiceImpl implements PGPKeyService {
                 if (key1.getKeyId() == key2.getKeyId()) {
                     return 0;
                 }
-                return 1;
+                return key1.getKeyId() < key2.getKeyId() ? -1 : 1;
             }
         });
         duplicatesRemoved.addAll(internalKeyMappings);
@@ -209,7 +211,11 @@ public class PGPKeyServiceImpl implements PGPKeyService {
             if (internalMapping.isLocal()) {
                 GuardKeys key = keyService.getKeys(email,internalMapping.getKeyId());
                 if (key != null) {
-                    ret.add(key.getPGPPublicKeyRing());
+                    if (key.isCurrent()) {
+                        ret.add(0, key.getPGPPublicKeyRing());  // always add current key as the first
+                    } else {
+                        ret.add(key.getPGPPublicKeyRing());
+                    }
                 }
             }
         }
@@ -248,7 +254,7 @@ public class PGPKeyServiceImpl implements PGPKeyService {
      */
     @Override
     public PGPPrivateKey getPGPSignKey(PGPSecretKeyRing keyRing, String password, String salt) throws OXException {
-        PGPPrivateKey signingKey = getDecodedPrivate(PGPUtil.getSigningKey(keyRing), password, salt);
+        PGPPrivateKey signingKey = getDecodedPrivate(PGPKeysUtil.getSigningKey(keyRing), password, salt);
         if (signingKey == null) {
             LOG.error("Unable to find PGP signing key");
         }
@@ -296,7 +302,7 @@ public class PGPKeyServiceImpl implements PGPKeyService {
     @Override
     public PGPPublicKeyRing addUID(PGPPrivateKey privateKey, PGPPublicKeyRing publicKeyRing, String userId) throws OXException {
         try {
-            return PGPUtil.addUID(publicKeyRing, privateKey, userId);
+        	return UserIDCreator.addUID(publicKeyRing, privateKey, userId);
         } catch (PGPException e) {
             throw PGPKeyExceptionCodes.PGP_ERROR.create(e, e.getMessage());
         }
@@ -680,7 +686,7 @@ public class PGPKeyServiceImpl implements PGPKeyService {
 
             PGPSecretKeyRing newkeyring = null;
             try {
-                newkeyring = PGPUtil.duplicateSecretKeyRing(keys.getPGPSecretKeyRing(), pgpPassword, newpass, getPGPEncryptedData());
+                newkeyring = PGPKeysUtil.duplicateSecretKeyRing(keys.getPGPSecretKeyRing(), pgpPassword, newpass, getPGPEncryptedData());
             } catch (Exception ex) {
                 if (ex.getMessage().contains("checksum")) {
                     throw PGPKeyExceptionCodes.PGP_ERROR.create(ex, "Bad password");
@@ -699,7 +705,7 @@ public class PGPKeyServiceImpl implements PGPKeyService {
             try {
                 PGPPrivateKey pkey = PGPUtil.decodePrivate(keys.getPGPSecretKey(), guardPassword, keys.getSalt());
                 if (pkey == null) {
-                    LOG.error("Error decoding PGP Private key for inport");
+                    LOG.error("Error decoding PGP Private key for import");
                     return null;
                 }
             } catch (PGPException e) {
