@@ -64,6 +64,8 @@ import com.openexchange.guard.common.java.Strings;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.configuration.GuardProductName;
 import com.openexchange.guard.configuration.GuardProperty;
+import com.openexchange.guard.email.storage.ogEmail.Email;
+import com.openexchange.guard.email.storage.ogEmail.EmailStorage;
 import com.openexchange.guard.mailcreator.MailCreatorService;
 import com.openexchange.guard.translation.ConditionalVissibleTemplateTransformation;
 import com.openexchange.guard.translation.GuardTranslationService;
@@ -78,7 +80,6 @@ import com.openexchange.guard.translation.TemplateTransformation;
 public class MailCreatorServiceImpl implements MailCreatorService {
 
     private static Logger LOG = LoggerFactory.getLogger(MailCreatorServiceImpl.class);
-
     public static final String OUTSITE_TEMPLATE = "";
 
     public static final String PASSWORD_EMAIL_TEMPLATE = "";
@@ -175,7 +176,7 @@ public class MailCreatorServiceImpl implements MailCreatorService {
             to = to + ", ";
         }
         if (name.length() > 0) {
-                to = to + name + "<" + email + ">";
+                to = to + flatten(name, email);
         } else {
             to = to + email;
         }
@@ -191,7 +192,7 @@ public class MailCreatorServiceImpl implements MailCreatorService {
             to = to + ", ";
         }
         if (name.length() > 0) {
-            to = to + name + "<" + email + ">";
+            to = to + flatten(name, email);
         } else {
             to = to + email;
         }
@@ -207,7 +208,7 @@ public class MailCreatorServiceImpl implements MailCreatorService {
             to = to + ", ";
         }
         if (name.length() > 0) {
-            to = to + name + "<" + email + ">";
+            to = to + flatten(name, email);
         } else {
             to = to + email;
         }
@@ -220,12 +221,19 @@ public class MailCreatorServiceImpl implements MailCreatorService {
     public JsonObject addFrom(JsonObject mail, String name, String email) {
         String from = email;
         if (name != null && name.length() > 0) {
-            from = name + "<" + email + ">";
+            from = flatten(name, email);
         }
         mail.getAsJsonObject("data").add("from", new JsonPrimitive(from));
         return (mail);
     }
 
+    private String flatten (String name, String email) {
+        if (name.contains(",")) {  // If contains comma, enclose in quotes
+            name = "\"" + name + "\"";
+        }
+        return (name + "<" + email + ">");
+    }
+
     @Override
     public JsonObject addSubject(JsonObject mail, String subject) {
         mail.getAsJsonObject("data").add("subject", new JsonPrimitive(subject));
@@ -272,6 +280,9 @@ public class MailCreatorServiceImpl implements MailCreatorService {
      * @throws OXException
      */
     private JsonObject getPasswordEmail(String to, String sendername, String from, String from2, String password, String lang, int templId, String guestmessage, String templateName, String host, int userid, int cid) throws OXException {
+        if(guestmessage == null) {
+            guestmessage = "";
+        }
         JsonObject email = createBlankMail();
         email = addTo(email, to, to);
         email = addFrom(email, from, from2);
@@ -350,15 +361,29 @@ public class MailCreatorServiceImpl implements MailCreatorService {
      */
     @Override
     public ArrayList<String> getFromAddress(String name, String email, int userid, int cid) throws OXException {
+    	
+    	EmailStorage emailStorage = Services.getService(EmailStorage.class);
+
         ArrayList<String> answer = new ArrayList<String>();
         // Check if Backend has a from address for this person in config cascade
         String fromemail = null;
         GuardConfigurationService guardConfigService = Services.getService(GuardConfigurationService.class);
         if (userid != 0) {
-            fromemail = guardConfigService.getProperty(GuardProperty.fromEmail, userid, cid);
+        	fromemail = guardConfigService.getProperty(GuardProperty.fromEmail, userid, cid);
+
+        	if ( (fromemail == null || fromemail.isEmpty()) && cid < 0) {
+        		//Guests only:
+        		//Workaround for Bug 59842 - password reset from address override by config cascade not working
+        		//Explicit query fromEmail from the contextSet (and only the contextSet) for a user in the guest's context 
+        		List<Email> forContext = emailStorage.getForContext(cid * -1, 1);
+        		Email userInContext = forContext != null && forContext.size() > 0 ? forContext.get(0) : null;
+        		if(userInContext != null) {
+        			fromemail = guardConfigService.getContextSetStringProperty(GuardProperty.fromEmail, userInContext.getUserId(), userInContext.getContextId(), null);
+        		}
+        	}
         }
         // If no config cascade
-        if (fromemail == null) {
+        if (fromemail == null || fromemail.isEmpty()) {
             // Check if we have global configuration
             String fromAddress = guardConfigService.getProperty(GuardProperty.passwordFromAddress);
             String fromName = guardConfigService.getProperty(GuardProperty.passwordFromName);
