@@ -123,4 +123,12 @@ public interface GuardMaintenanceMBean {
      */
     void resetGuest(String email, boolean force) throws MBeanException;
 
+    /**
+     * Changes email, userid, or context of a user Identified by email
+     * @param email
+     * @param newEmail
+     * @throws MBeanException
+     */
+    void changeUser(String email, String newEmail) throws MBeanException;
+
 }
