@@ -130,7 +130,7 @@ public class GuardMaintenanceMBeanImpl extends StandardMBean implements GuardMai
 
     @Override
     public void deleteUser(String email) throws MBeanException {
-    	try {
+        try {
             maintenanceService.delete(email);
         } catch (OXException e) {
             throw new MBeanException(e);
@@ -145,4 +145,17 @@ public class GuardMaintenanceMBeanImpl extends StandardMBean implements GuardMai
             throw new MBeanException(e);
         }
     }
+
+    /* (non-Javadoc)
+     * @see com.openexchange.guard.management.maintenance.GuardMaintenanceMBean#changeUser(java.lang.String, java.lang.String, int, int)
+     */
+    @Override
+    public void changeUser(String email, String newEmail) throws MBeanException {
+        try {
+            maintenanceService.changeUser(email, newEmail);
+        } catch (OXException e) {
+            throw new MBeanException(e);
+        }
+
+    }
 }
