@@ -63,7 +63,7 @@ import com.openexchange.exception.OXException;
  */
 public interface GuardNotificationService {
 
-    void send(JsonObject email) throws OXException;
+    void send(JsonObject email, String senderIp) throws OXException;
 
     /**
      * Sends the mail message
@@ -72,11 +72,11 @@ public interface GuardNotificationService {
      * @param attachments A list with attachments
      * @throws OXException if an error occurred and the mail couldn't get send
      */
-    void send(JsonObject email, List<BodyPart> attachments) throws OXException;
+    void send(JsonObject email, List<BodyPart> attachments, String senderIp) throws OXException;
 
-    void send(JsonObject email, String lang) throws OXException;
+    void send(JsonObject email, String lang, String senderIp) throws OXException;
 
-    void send(JsonObject email, List<BodyPart> attachments, String sender, String lang, String messageId) throws OXException;
+    void send(JsonObject email, List<BodyPart> attachments, String sender, int senderCid, String lang, String messageId, String senderIp) throws OXException;
 
     /**
      * Sends Mail message using SMTP Server
@@ -86,5 +86,5 @@ public interface GuardNotificationService {
      * @param lang The language
      * @throws OXException if an error occurred and the mail couldn't get send
      */
-    void sendMessage(Message msg, String sender, String lang) throws OXException;
+    void sendMessage(Message msg, String sender, int senderCid, String lang, String senderIp) throws OXException;
 }
