@@ -67,7 +67,6 @@ import javax.mail.Multipart;
 import javax.mail.PasswordAuthentication;
 import javax.mail.Session;
 import javax.mail.Transport;
-import javax.mail.internet.AddressException;
 import javax.mail.internet.InternetAddress;
 import javax.mail.internet.InternetHeaders;
 import javax.mail.internet.MimeBodyPart;
@@ -87,6 +86,7 @@ import com.openexchange.guard.configuration.GuardProperty;
 import com.openexchange.guard.notification.GuardNotificationMessages;
 import com.openexchange.guard.notification.GuardNotificationService;
 import com.openexchange.guard.notification.exceptions.GuardNotificationExceptionCodes;
+import com.openexchange.guard.ratifier.GuardRatifierService;
 import com.openexchange.guard.translation.GuardTranslationService;
 import net.htmlparser.jericho.Source;
 
@@ -100,30 +100,44 @@ public class GuardNotificationServiceImpl implements GuardNotificationService {
 
     private static final int MAX_MIME_LINE_LENGTH = 998;
     private static final int MAX_IMAGE_LINE_LENGTH = 76;
+    private static final String X_ORIG_IP = "X-Originating-IP";
 
     private static Logger LOG = LoggerFactory.getLogger(GuardNotificationServiceImpl.class);
+    boolean attachSenderIp;
+    GuardRatifierService guardRatifierService;
+    GuardConfigurationService guardConfigService;
+
+    public GuardNotificationServiceImpl(GuardRatifierService guardRatifierService, GuardConfigurationService guardConfigService, boolean attachSenderIp) {
+        this.guardRatifierService = guardRatifierService;
+        this.guardConfigService = guardConfigService;
+        this.attachSenderIp = attachSenderIp;
+    }
 
     @Override
-    public void send(final JsonObject email) throws OXException {
+    public void send(final JsonObject email, String senderIp) throws OXException {
         final GuardConfigurationService guardConfigService = Services.getService(GuardConfigurationService.class);
-        send(email, null, "", guardConfigService.getProperty(GuardProperty.defaultLanguage), getMessageID());
+        send(email, null, "", 0, guardConfigService.getProperty(GuardProperty.defaultLanguage), getMessageID(), senderIp);
     }
 
     @Override
-    public void send(final JsonObject email, String lang) throws OXException {
-        send (email, null, "", lang, getMessageID());
+    public void send(final JsonObject email, String lang, String senderIp) throws OXException {
+        send (email, null, "", 0, lang, getMessageID(), senderIp);
     }
 
     @Override
-    public void send(final JsonObject email, final List<BodyPart> attachments) throws OXException {
+    public void send(final JsonObject email, final List<BodyPart> attachments, String senderIp) throws OXException {
         final GuardConfigurationService guardConfigService = Services.getService(GuardConfigurationService.class);
-        send(email, attachments, "", guardConfigService.getProperty(GuardProperty.defaultLanguage), getMessageID());
+        send(email, attachments, "", 0, guardConfigService.getProperty(GuardProperty.defaultLanguage), getMessageID(), senderIp);
+    }
+
+    private boolean isLocal (int cid) {
+        return (cid > 0);
     }
 
     @Override
-    public void send(JsonObject email, final List<BodyPart> attachments, final String sender, final String lang, final String messageId) throws OXException {
+    public void send(JsonObject email, final List<BodyPart> attachments, final String sender, int senderCid, final String lang, final String messageId, String senderIp) throws OXException {
         try {
-            final Session session = getSession();
+            final Session session = getSession(isLocal(senderCid));
             final MimeMessage message = new MimeMessage(session);
             email = email.get("data").getAsJsonObject();
             // Parse Json for email headers
@@ -182,6 +196,9 @@ public class GuardNotificationServiceImpl implements GuardNotificationService {
                 }
 
             }
+
+            addOrigIp(message, senderIp);
+
             // From
             InternetAddress fromaddr = null;
             InternetAddress replyaddr = null;
@@ -306,8 +323,8 @@ public class GuardNotificationServiceImpl implements GuardNotificationService {
     }
 
     @Override
-    public void sendMessage(final Message msg, final String sender, final String lang) throws OXException {
-        final Session session = getSession();
+    public void sendMessage(final Message msg, final String sender, int senderCid, final String lang, String senderIp) throws OXException {
+        final Session session = getSession(isLocal(senderCid));
         Transport transport;
         try {
             if (!sender.equals("")) {
@@ -318,6 +335,7 @@ public class GuardNotificationServiceImpl implements GuardNotificationService {
                 fromaddr.setAddress(sender);
                 msg.setFrom(fromaddr);
             }
+            addOrigIp(msg, senderIp);
             transport = session.getTransport("smtp");
             transport.connect();
             transport.sendMessage(msg, msg.getAllRecipients());
@@ -328,13 +346,28 @@ public class GuardNotificationServiceImpl implements GuardNotificationService {
         }
     }
 
+    /**
+     * Add X-Originating-IP header if configured
+     * @param msg
+     * @param senderIp
+     * @throws MessagingException
+     */
+    private void addOrigIp (Message msg, String senderIp) throws MessagingException {
+        if (attachSenderIp) {  // If attach Originating IP header requested, add now
+            senderIp = guardRatifierService.verifyIPAddress(senderIp);  // Verify
+            if (senderIp != null) {
+                msg.addHeader(X_ORIG_IP, senderIp);
+            }
+        }
+    }
+
     /**
      * Returns a javax.mail.Session
      *
      * @return a javax.mail.Session
      * @throws OXException if the GuardConfigurationService is absent
      */
-    private Session getSession() throws OXException {
+    private Session getSession(boolean local) throws OXException {
         final GuardConfigurationService guardConfigService = Services.getService(GuardConfigurationService.class);
         final String server = guardConfigService.getProperty(GuardProperty.guestSMTPServer);
         final int port = guardConfigService.getIntProperty(GuardProperty.guestSMTPPort);
@@ -353,6 +386,13 @@ public class GuardNotificationServiceImpl implements GuardNotificationService {
         if (guardConfigService.getBooleanProperty(GuardProperty.useStartTLS)) {
             prop.put("mail.smtp.starttls.enable", "true");
         }
+        // Bug 55211, add guestSMTPMailFrom only for replies/system emails.
+        if (!local) {
+            String mailFrom = guardConfigService.getProperty(GuardProperty.guestSMTPMailFrom);
+            if (mailFrom != null && !mailFrom.isEmpty()) {
+                prop.put("mail.smtp.from", mailFrom);
+            }
+        }
         LOG.debug("Using SMTP server " + server + ":" + port + ", TLS=" + guardConfigService.getBooleanProperty(GuardProperty.useStartTLS));
         Session session = null;
         if (authenticate) {
