@@ -62,9 +62,9 @@ import com.openexchange.exception.OXException;
 import com.openexchange.guard.common.util.CipherUtil;
 import com.openexchange.guard.exceptions.GuardAuthExceptionCodes;
 import com.openexchange.guard.keymanagement.commons.GuardKeys;
-import com.openexchange.guard.keymanagement.commons.util.PGPUtil;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
-import com.openexchange.guard.pgpcore.commons.PGPKeyRetrievalStrategy;
+import com.openexchange.pgp.core.PGPKeyRetrievalStrategy;
+import com.openexchange.pgp.core.PGPSecretKeyDecoder;
 
 /**
  * {@link DBKeyRetrievalStrategy}
@@ -88,17 +88,26 @@ public class DBKeyRetrievalStrategy implements PGPKeyRetrievalStrategy {
         this.guardKeyService = guardKeyService;
     }
 
-    private boolean hasUserId(PGPSecretKey key, String userIdentity) {
-        Iterator<String> userIDs = key.getUserIDs();
+    private boolean hasUserId(Iterator<String> userIDs, String userIdentity) {
         while(userIDs.hasNext()) {
             String id = userIDs.next();
-            if(id.contains(userIdentity)) {
+            if(id != null && id.toLowerCase().contains(userIdentity.toLowerCase())) {
                 return true;
             }
         }
         return false;
     }
 
+    private boolean hasUserId(PGPSecretKey key, String userIdentity) {
+        if (key == null) return false;
+        return hasUserId(key.getUserIDs(), userIdentity);
+    }
+
+    private boolean hasUserId(PGPPublicKey key, String userIdentity) {
+        if (key == null) return false;
+        return hasUserId(key.getUserIDs(), userIdentity);
+    }
+
     /**
      * Retrieves Guard Key information for a given key id
      *
@@ -120,7 +129,7 @@ public class DBKeyRetrievalStrategy implements PGPKeyRetrievalStrategy {
      */
     private PGPPrivateKey decodePrivateKey(PGPSecretKey secretKey, char[] password) throws Exception {
         try {
-            return PGPUtil.decodePrivate(secretKey, new String(password));
+            return PGPSecretKeyDecoder.decodePrivateKey(secretKey, password);
         } catch (PGPException e) {
             throw GuardAuthExceptionCodes.BAD_PASSWORD.create();
         }
@@ -132,6 +141,9 @@ public class DBKeyRetrievalStrategy implements PGPKeyRetrievalStrategy {
      * @return
      */
     private char[] hashPassword(char[] password, String salt) {
+        if (password == null) {
+            return null;
+        }
         return CipherUtil.getSHA(new String(password), salt).toCharArray();
     }
 
@@ -145,7 +157,12 @@ public class DBKeyRetrievalStrategy implements PGPKeyRetrievalStrategy {
         GuardKeys guardKeys = getGuardKeyById(keyId);
         if (guardKeys != null) {
             PGPSecretKeyRing pgpSecretKeyRing = guardKeys.getPGPSecretKeyRing();
+            PGPPublicKeyRing pgpPublicKeyRing = guardKeys.getPGPPublicKeyRing();
+            if (pgpSecretKeyRing == null) {
+                return null;
+            }
             PGPSecretKey secretKey = pgpSecretKeyRing.getSecretKey(keyId);
+            PGPPublicKey publicKey = pgpPublicKeyRing.getPublicKey(keyId);
             if (secretKey != null) {
                 if(userIdentity == null) {
                     //Do not check for userIdentity
@@ -153,16 +170,24 @@ public class DBKeyRetrievalStrategy implements PGPKeyRetrievalStrategy {
                 }
                 else {
                     //Check if we find the userIdentity within the key, or master-key
-                    if(hasUserId(secretKey,userIdentity) || hasUserId(pgpSecretKeyRing.getSecretKey()/*masterKey*/,userIdentity)) {
+                    //Usually we would just need to search through the secret keys to find the identity, but since Guard stores public- and private-
+                    //key material separately, we also lookup though the public keys in case the key material differs.
+                    if(hasUserId(secretKey,userIdentity) || hasUserId(pgpSecretKeyRing.getSecretKey()/*masterKey*/,userIdentity) ||
+                       hasUserId(publicKey, userIdentity) || hasUserId(pgpPublicKeyRing.getPublicKey() /*masterKey*/, userIdentity)) {
                         return decodePrivateKey(secretKey, hashPassword(password,guardKeys.getSalt()));
                     }
+                    else {
+                        logger.info("Unable to find Userid {} in keyid {}.", userIdentity, Long.toString(keyId));
+                    }
                 }
             }
             else {
-                logger.debug("Unable to extract PGPSecretKey with key id %s from PGPSecretKeyRing.", Long.toString(keyId));
+                logger.error("Unable to extract PGPSecretKey with key id {} from PGPSecretKeyRing.", Long.toString(keyId));
             }
         }
-        logger.debug("Unable to find PGPSecretKey for key id %s.", Long.toString(keyId));
+        else {
+            logger.info("Unable to find PGPSecretKey for key id {}.", Long.toString(keyId));
+        }
         return null;
     }
 
