@@ -59,15 +59,18 @@ import org.slf4j.Logger;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.common.util.CipherUtil;
 import com.openexchange.guard.keymanagement.commons.GuardKeys;
-import com.openexchange.guard.keymanagement.commons.util.PGPUtil;
-import com.openexchange.guard.pgpcore.commons.PGPDecrypter;
-import com.openexchange.guard.pgpcore.commons.PGPEncrypter;
-import com.openexchange.guard.pgpcore.commons.PGPKeyRetrievalStrategy;
-import com.openexchange.guard.pgpcore.commons.PGPSignatureVerificationResult;
-import com.openexchange.guard.pgpcore.commons.GuardKeyRingRetrievalStrategy;
+import com.openexchange.guard.keymanagement.commons.RecipKey;
+import com.openexchange.guard.keymanagement.services.GuardKeyService;
+import com.openexchange.guard.keymanagement.storage.OGPGPKeysStorage;
+import com.openexchange.guard.pgpcore.services.GuardKeyRingRetrievalStrategy;
 import com.openexchange.guard.pgpcore.services.PGPCryptoService;
-import com.openexchange.guard.pgpcore.services.UserIdentity;
 import com.openexchange.guard.pgpcore.services.exceptions.PGPCoreServicesExceptionCodes;
+import com.openexchange.guard.user.UserIdentity;
+import com.openexchange.pgp.core.PGPDecrypter;
+import com.openexchange.pgp.core.PGPEncrypter;
+import com.openexchange.pgp.core.PGPKeyRetrievalStrategy;
+import com.openexchange.pgp.core.PGPSignatureVerificationResult;
+import com.openexchange.pgp.keys.tools.PGPKeysUtil;
 
 /**
  * {@link PGPCryptoServiceImpl}
@@ -77,9 +80,10 @@ import com.openexchange.guard.pgpcore.services.exceptions.PGPCoreServicesExcepti
  */
 public class PGPCryptoServiceImpl implements PGPCryptoService {
 
-    private final PGPKeyRetrievalStrategy pgpKeyRetrievalStrategy;
     private final GuardKeyRingRetrievalStrategy recipientKeyRingRetrievalStrategy;
     private static final Logger logger = org.slf4j.LoggerFactory.getLogger(PGPCryptoServiceImpl.class);
+    private GuardKeyService guardKeyService;
+    private OGPGPKeysStorage keyStorage;
 
     /**
      * Initializes a new {@link PGPCryptoServiceImpl}.
@@ -87,10 +91,30 @@ public class PGPCryptoServiceImpl implements PGPCryptoService {
      * @param pgpKeyRetrievalStrategy the strategy for retrieving keys for decryption.
      * @param recipientKeyRingRetrievalStrategy the strategy for retrieving keys for encryption
      */
-    public PGPCryptoServiceImpl(GuardKeyRingRetrievalStrategy recipientKeyRingRetrievalStrategy,
-                                PGPKeyRetrievalStrategy pgpKeyRetrievalStrategy) {
+    public PGPCryptoServiceImpl(GuardKeyRingRetrievalStrategy recipientKeyRingRetrievalStrategy, GuardKeyService guardKeyService, OGPGPKeysStorage keyStorage) {
         this.recipientKeyRingRetrievalStrategy = recipientKeyRingRetrievalStrategy;
-        this.pgpKeyRetrievalStrategy = pgpKeyRetrievalStrategy;
+        this.guardKeyService = guardKeyService;
+        this.keyStorage = keyStorage;
+    }
+
+    /**
+     * Internal method to get the strategy for retrieving PGP keys.
+     *
+     * @param userId The user id of the caller
+     * @param contextId The context id of the caller
+     * @return The strategy
+     */
+    private PGPKeyRetrievalStrategy getPgpKeyRetrievalStrategy(int userId, int contextId) {
+        return new DefaultPGPKeyRetrievalStrategy(guardKeyService, keyStorage, userId, contextId);
+    }
+
+    /**
+     * Internal method to get the strategy for retrieving PGP keys.
+     *
+     * @return The strategy
+     */
+    private PGPKeyRetrievalStrategy getPgpKeyRetrievalStrategy() {
+        return new DBKeyRetrievalStrategy(guardKeyService);
     }
 
     /**
@@ -105,16 +129,14 @@ public class PGPCryptoServiceImpl implements PGPCryptoService {
         ArrayList<PGPPublicKey> ret = new ArrayList<>();
         for (String recipient : recipients) {
             GuardKeys guardKeys = recipientKeyRingRetrievalStrategy.getKeyRingForRecipient(recipient);
-            if(guardKeys != null) {
+            if (guardKeys != null) {
                 PGPPublicKey key = guardKeys.getPGPPublicKey();
                 if (key != null) {
                     ret.add(key);
-                }
-                else {
+                } else {
                     throw PGPCoreServicesExceptionCodes.RECIPIENT_KEY_NOT_FOUND.create(recipient);
                 }
-            }
-            else {
+            } else {
                 throw PGPCoreServicesExceptionCodes.RECIPIENT_KEY_NOT_FOUND.create(recipient);
             }
         }
@@ -132,8 +154,7 @@ public class PGPCryptoServiceImpl implements PGPCryptoService {
         GuardKeys guardKeys = recipientKeyRingRetrievalStrategy.getKeyRingForRecipient(identity);
         if (guardKeys != null) {
             return guardKeys;
-        }
-        else {
+        } else {
             throw PGPCoreServicesExceptionCodes.SIGNING_KEY_NOT_FOUND.create(identity);
         }
     }
@@ -146,11 +167,10 @@ public class PGPCryptoServiceImpl implements PGPCryptoService {
      * @throws OXException If no signing key was found
      */
     PGPSecretKey getSignerKey(GuardKeys guardKey) throws OXException {
-        PGPSecretKey signingKey = PGPUtil.getSigningKey(guardKey.getPGPSecretKeyRing());
+        PGPSecretKey signingKey = PGPKeysUtil.getSigningKey(guardKey.getPGPSecretKeyRing());
         if (signingKey != null) {
             return signingKey;
-        }
-        else {
+        } else {
             throw PGPCoreServicesExceptionCodes.SIGNING_KEY_NOT_FOUND.create(guardKey.getKeyid());
         }
     }
@@ -159,6 +179,15 @@ public class PGPCryptoServiceImpl implements PGPCryptoService {
         return l.toString().replace("[", "").replace("]", "").replace(", ", ",");
     }
 
+    private String keyListToString(PGPPublicKey... keys) {
+        StringBuilder builder = new StringBuilder();
+        for (PGPPublicKey key : keys) {
+            builder.append(key.getKeyID());
+            builder.append(", ");
+        }
+        return builder.toString();
+    }
+
     /*
      * (non-Javadoc)
      *
@@ -177,6 +206,32 @@ public class PGPCryptoServiceImpl implements PGPCryptoService {
         }
     }
 
+    /*
+     * (non-Javadoc)
+     *
+     * @see com.openexchange.guard.pgpcore.services.PGPCryptoService#encrypt(java.io.InputStream, java.io.OutputStream, boolean, org.bouncycastle.openpgp.PGPPublicKey[])
+     */
+    @Override
+    public void encrypt(InputStream input, OutputStream output, boolean armored, RecipKey... recipientKeys) throws OXException {
+        try {
+            //Getting recipient keys suitable for encryption
+            List<PGPPublicKey> pgpRecipientKeysList = new ArrayList<PGPPublicKey>();
+            for (RecipKey recipientKey : recipientKeys) {
+                final PGPPublicKey encryptionKey = recipientKey.getEncryptionKey();
+                if(encryptionKey != null) {
+                    pgpRecipientKeysList.add(encryptionKey);
+                }
+            }
+            PGPPublicKey[] pgpRecipientKeys = pgpRecipientKeysList.toArray(new PGPPublicKey[pgpRecipientKeysList.size()]);
+            logger.debug("Encrypting data for recipients: " + keyListToString(pgpRecipientKeys) + ". ASCII-Armor = " + armored + ".");
+            new PGPEncrypter().encrypt(input, output, armored, pgpRecipientKeys);
+        } catch (OXException e) {
+            throw e;
+        } catch (Exception e) {
+            throw PGPCoreServicesExceptionCodes.ENCRYPTION_ERROR.create(e, e.getMessage());
+        }
+    }
+
     /*
      * (non-Javadoc)
      *
@@ -189,13 +244,38 @@ public class PGPCryptoServiceImpl implements PGPCryptoService {
             logger.debug("Encrypting data for recipients: " + listToString(recipients) + ". Signging as: " + signerIdentity.getIdentity() + ". ASCII-Armor = " + armored + ".");
             PGPPublicKey[] recipientKeys = getRecipientKeys(recipients);
             GuardKeys guardKey = getSignerGuardKey(signerIdentity.getIdentity());
-            PGPSecretKey signingKey = getSignerKey(guardKey);
+            PGPSecretKey signingPGPKey = getSignerKey(guardKey);
             char[] hashedPassword = CipherUtil.getSHA(new String(signerIdentity.getPassword()), guardKey.getSalt()).toCharArray();
-            new PGPEncrypter().encryptSigned(input, output, armored, signingKey, hashedPassword, recipientKeys);
+            new PGPEncrypter().encryptSigned(input, output, armored, signingPGPKey, hashedPassword, recipientKeys);
         } catch (OXException e) {
             throw e;
         } catch (Exception e) {
-            PGPCoreServicesExceptionCodes.ENCRYPTION_ERROR.create(e, e.getMessage());
+            throw PGPCoreServicesExceptionCodes.ENCRYPTION_ERROR.create(e, e.getMessage());
+        }
+    }
+
+    /*
+     * (non-Javadoc)
+     *
+     * @see com.openexchange.guard.pgpcore.services.PGPCryptoService#encryptSigned(java.io.InputStream, java.io.OutputStream, boolean, org.bouncycastle.openpgp.PGPSecretKey, java.lang.String, org.bouncycastle.openpgp.PGPPublicKey[])
+     */
+    @Override
+    public void encryptSigned(InputStream input, OutputStream output, boolean armored, GuardKeys signingKey, String password, RecipKey... recipientKeys) throws OXException {
+        try {
+            //Getting recipient keys suitable for encryption
+            List<PGPPublicKey> pgpRecipientKeysList = new ArrayList<PGPPublicKey>();
+            for (RecipKey recipientKey : recipientKeys) {
+                pgpRecipientKeysList.add(recipientKey.getEncryptionKey());
+            }
+            PGPPublicKey[] pgpRecipientKeys = pgpRecipientKeysList.toArray(new PGPPublicKey[pgpRecipientKeysList.size()]);
+            PGPSecretKey signingPGPKey = getSignerKey(signingKey);
+            char[] hashedPassword = CipherUtil.getSHA(password, signingKey.getSalt()).toCharArray();
+            logger.debug("Encrypting data for recipients: " + keyListToString(pgpRecipientKeys) + ". Signging as: " + signingKey.getEmail() + ". ASCII-Armor = " + armored + ".");
+            new PGPEncrypter().encryptSigned(input, output, armored, signingPGPKey, hashedPassword, pgpRecipientKeys);
+        } catch (OXException e) {
+            throw e;
+        } catch (Exception e) {
+            throw PGPCoreServicesExceptionCodes.ENCRYPTION_ERROR.create(e, e.getMessage());
         }
     }
 
@@ -208,7 +288,14 @@ public class PGPCryptoServiceImpl implements PGPCryptoService {
     public List<PGPSignatureVerificationResult> decrypt(InputStream input, OutputStream output, UserIdentity recipient) throws OXException {
         try {
             logger.debug("Decrypting data for : " + recipient.getIdentity());
-            PGPDecrypter decrypter = new PGPDecrypter(pgpKeyRetrievalStrategy);
+            PGPDecrypter decrypter = null;
+            if(recipient.isGuardUser()) {
+                decrypter = new PGPDecrypter(
+                    getPgpKeyRetrievalStrategy(recipient.getGuardUser().getId(), recipient.getGuardUser().getContextId()));
+            }
+            else {
+                decrypter = new PGPDecrypter(getPgpKeyRetrievalStrategy());
+            }
             return decrypter.decrypt(input, output, recipient.getIdentity(), recipient.getPassword());
         } catch (OXException e) {
             throw e;
@@ -216,4 +303,24 @@ public class PGPCryptoServiceImpl implements PGPCryptoService {
             throw PGPCoreServicesExceptionCodes.DECRYPTION_ERROR.create(e, e.getMessage());
         }
     }
+
+    /*
+     * (non-Javadoc)
+     *
+     * @see com.openexchange.guard.pgpcore.services.PGPCryptoService#decrypt(java.io.InputStream, java.io.OutputStream, com.openexchange.guard.keymanagement.commons.GuardKeys, java.lang.String)
+     */
+    @Override
+    public List<PGPSignatureVerificationResult> decrypt(InputStream input, OutputStream output, GuardKeys key, String password) throws OXException {
+        try {
+            logger.debug("Decrypting data for : " + key.getEmail());
+            PGPDecrypter decrypter = new PGPDecrypter(
+                key.getPGPSecretKey() /* using a specific key */,
+                getPgpKeyRetrievalStrategy(key.getUserid(), key.getContextid()) /* strategy used to get public keys for signature verification */);
+            return decrypter.decrypt(input, output, key.getEmail(), password.toCharArray());
+        } catch (OXException e) {
+            throw e;
+        } catch (Exception e) {
+            throw PGPCoreServicesExceptionCodes.DECRYPTION_ERROR.create(e, e.getMessage());
+        }
+    }
 }
