@@ -56,15 +56,15 @@ import org.bouncycastle.openpgp.PGPSecretKey;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.common.util.CipherUtil;
 import com.openexchange.guard.keymanagement.commons.GuardKeys;
-import com.openexchange.guard.keymanagement.commons.util.PGPUtil;
-import com.openexchange.guard.pgpcore.commons.PGPKeyRetrievalStrategy;
-import com.openexchange.guard.pgpcore.commons.PGPSignatureCreator;
-import com.openexchange.guard.pgpcore.commons.PGPSignatureVerificationResult;
-import com.openexchange.guard.pgpcore.commons.PGPSignatureVerifier;
-import com.openexchange.guard.pgpcore.commons.GuardKeyRingRetrievalStrategy;
+import com.openexchange.pgp.core.PGPKeyRetrievalStrategy;
+import com.openexchange.pgp.core.PGPSignatureCreator;
+import com.openexchange.pgp.core.PGPSignatureVerificationResult;
+import com.openexchange.pgp.core.PGPSignatureVerifier;
+import com.openexchange.pgp.keys.tools.PGPKeysUtil;
+import com.openexchange.guard.pgpcore.services.GuardKeyRingRetrievalStrategy;
 import com.openexchange.guard.pgpcore.services.PGPSigningService;
-import com.openexchange.guard.pgpcore.services.UserIdentity;
 import com.openexchange.guard.pgpcore.services.exceptions.PGPCoreServicesExceptionCodes;
+import com.openexchange.guard.user.UserIdentity;
 
 /**
  * {@link PGPSigningServiceImpl}
@@ -112,7 +112,7 @@ public class PGPSigningServiceImpl implements PGPSigningService {
      * @throws OXException If no signing key was found
      */
     PGPSecretKey getSignerKey(GuardKeys guardKey) throws OXException {
-        PGPSecretKey signingKey = PGPUtil.getSigningKey(guardKey.getPGPSecretKeyRing());
+        PGPSecretKey signingKey = PGPKeysUtil.getSigningKey(guardKey.getPGPSecretKeyRing());
         if (signingKey != null) {
             return signingKey;
         }
