@@ -63,11 +63,12 @@ import com.openexchange.exception.OXException;
 import com.openexchange.guard.cipher.GuardCipherService;
 import com.openexchange.guard.common.util.CipherUtil;
 import com.openexchange.guard.keymanagement.commons.GuardKeys;
-import com.openexchange.guard.pgpcore.commons.GuardKeyRingRetrievalStrategy;
+import com.openexchange.guard.pgpcore.services.GuardKeyRingRetrievalStrategy;
 import com.openexchange.guard.pgpcore.services.TokenAuthenticationService;
-import com.openexchange.guard.pgpcore.services.UserIdentity;
 import com.openexchange.guard.pgpcore.services.exceptions.PGPCoreServicesExceptionCodes;
 import com.openexchange.guard.session.GuardSessionService;
+import com.openexchange.guard.user.GuardUserService;
+import com.openexchange.guard.user.UserIdentity;
 
 /**
  * {@link TokenAuthenticationServiceImpl}
@@ -80,6 +81,7 @@ public class TokenAuthenticationServiceImpl implements TokenAuthenticationServic
     private final GuardKeyRingRetrievalStrategy keyRingRetrievalStrategy;
     private final GuardSessionService guardSessionService;
     private final GuardCipherService guardCipherService;
+    private final GuardUserService guardUserService;
     private static final Logger logger = LoggerFactory.getLogger(TokenAuthenticationServiceImpl.class);
 
     /**
@@ -87,10 +89,15 @@ public class TokenAuthenticationServiceImpl implements TokenAuthenticationServic
      *
      * @param guardKeyService
      */
-    public TokenAuthenticationServiceImpl(GuardKeyRingRetrievalStrategy keyRingRetrievalStrategy, GuardSessionService guardSessionService, GuardCipherService guardCipherService) {
+    public TokenAuthenticationServiceImpl(
+        GuardKeyRingRetrievalStrategy keyRingRetrievalStrategy,
+        GuardSessionService guardSessionService,
+        GuardCipherService guardCipherService,
+        GuardUserService guardUserService) {
         this.keyRingRetrievalStrategy = keyRingRetrievalStrategy;
         this.guardSessionService = guardSessionService;
         this.guardCipherService = guardCipherService;
+        this.guardUserService = guardUserService;
     }
 
     /**
@@ -154,15 +161,23 @@ public class TokenAuthenticationServiceImpl implements TokenAuthenticationServic
      * @param json The json to create the UserIdentity from
      * @return The UserIdentity created from the given json, or null if the json does not provide all required information
      * @throws JSONException
+     * @throws OXException
      */
-    private UserIdentity createUserIdentity(JSONObject json) throws JSONException {
+    private UserIdentity createUserIdentity(JSONObject json) throws JSONException, OXException {
+        UserIdentity ret = null;
         if (json.has("UserIdentity") && json.has("Password")) {
-            return new UserIdentity(json.getString("UserIdentity"), json.getString("Password"));
+            ret = new UserIdentity(json.getString("UserIdentity"), json.getString("Password"));
         }
-        else if(json.has("email") && json.has("ox_password")) {
-            return new UserIdentity(json.getString("email"), json.getString("ox_password"));
+        else if(json.has("email") && json.has("encr_password")) {
+            ret = new UserIdentity(json.getString("email"), json.getString("encr_password"));
         }
-        return null;
+
+        if(json.has("user_id") && json.has("cid")) {
+            final int userId = json.getInt("user_id");
+            final int cid = json.getInt("cid");
+            ret.setGuardUser(guardUserService.getUser(cid, userId));
+        }
+        return ret;
     }
 
     /**
