@@ -2,12 +2,13 @@
 package com.openexchange.guard.pgpcore.services.impl.osgi;
 
 import com.openexchange.exception.OXException;
+import com.openexchange.pgp.core.PGPKeyRetrievalStrategy;
 import com.openexchange.guard.cipher.GuardCipherAlgorithm;
 import com.openexchange.guard.cipher.GuardCipherFactoryService;
 import com.openexchange.guard.cipher.GuardCipherService;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
-import com.openexchange.guard.pgpcore.commons.GuardKeyRingRetrievalStrategy;
-import com.openexchange.guard.pgpcore.commons.PGPKeyRetrievalStrategy;
+import com.openexchange.guard.keymanagement.storage.OGPGPKeysStorage;
+import com.openexchange.guard.pgpcore.services.GuardKeyRingRetrievalStrategy;
 import com.openexchange.guard.pgpcore.services.PGPCryptoService;
 import com.openexchange.guard.pgpcore.services.PGPSigningService;
 import com.openexchange.guard.pgpcore.services.TokenAuthenticationService;
@@ -19,6 +20,7 @@ import com.openexchange.guard.pgpcore.services.impl.PGPSigningServiceImpl;
 import com.openexchange.guard.pgpcore.services.impl.TokenAuthenticationServiceImpl;
 import com.openexchange.guard.pgpcore.services.impl.UserIDGuardKeyRingRetrievalStrategy;
 import com.openexchange.guard.session.GuardSessionService;
+import com.openexchange.guard.user.GuardUserService;
 import com.openexchange.osgi.HousekeepingActivator;
 
 public class PGPCoreServicesImplActivator extends HousekeepingActivator {
@@ -41,7 +43,7 @@ public class PGPCoreServicesImplActivator extends HousekeepingActivator {
      */
     @Override
     protected Class<?>[] getNeededServices() {
-        return new Class<?>[] { GuardCipherFactoryService.class, GuardKeyService.class, GuardSessionService.class };
+        return new Class<?>[] { GuardCipherFactoryService.class, GuardKeyService.class, GuardSessionService.class, GuardUserService.class, OGPGPKeysStorage.class};
     }
 
     /**
@@ -55,8 +57,15 @@ public class PGPCoreServicesImplActivator extends HousekeepingActivator {
         GuardKeyRingRetrievalStrategy guardKeyRingRetrievalStrategy = new CompositeGuardKeyRingRetrievalStrategy(new EmailGuardKeyRingRetrievalStrategy(getService(GuardKeyService.class)), new UserIDGuardKeyRingRetrievalStrategy(getService(GuardKeyService.class)));
         PGPKeyRetrievalStrategy pgpKeyRetrievalStrategy = new DBKeyRetrievalStrategy(getService(GuardKeyService.class));
         //Register the services
-        registerService(TokenAuthenticationService.class, new TokenAuthenticationServiceImpl(guardKeyRingRetrievalStrategy, getService(GuardSessionService.class), getCipherService()));
-        registerService(PGPCryptoService.class, new PGPCryptoServiceImpl(guardKeyRingRetrievalStrategy, pgpKeyRetrievalStrategy));
+        registerService(TokenAuthenticationService.class,
+            new TokenAuthenticationServiceImpl(guardKeyRingRetrievalStrategy,
+                                               getService(GuardSessionService.class),
+                                               getCipherService(),
+                                               getService(GuardUserService.class)));
+        registerService(PGPCryptoService.class,
+            new PGPCryptoServiceImpl(guardKeyRingRetrievalStrategy,
+                getService(GuardKeyService.class),
+                getService(OGPGPKeysStorage.class)));
         registerService(PGPSigningService.class, new PGPSigningServiceImpl(guardKeyRingRetrievalStrategy, pgpKeyRetrievalStrategy));
     }
 
