@@ -65,6 +65,7 @@ import java.util.Collections;
 import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
+import java.util.Locale;
 import java.util.Map;
 import java.util.Map.Entry;
 import javax.xml.parsers.DocumentBuilder;
@@ -80,6 +81,7 @@ import org.xml.sax.InputSource;
 import org.xml.sax.SAXException;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.common.java.Strings;
+import com.openexchange.guard.common.util.LocaleUtil;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.configuration.GuardProperty;
 import com.openexchange.guard.translation.GuardTranslationService;
@@ -472,6 +474,14 @@ public class GuardTranslationServiceImpl implements GuardTranslationService {
         return defaultCode;
     }
 
+    /* (non-Javadoc)
+     * @see com.openexchange.guard.translation.GuardTranslationService#getAvailableLocale(java.lang.String)
+     */
+    @Override
+    public Locale getAvailableLocale(String code) {
+        return LocaleUtil.getLocalFor(getAvailableCode(code));
+    }
+
     /*
      * (non-Javadoc)
      *
