@@ -68,6 +68,17 @@ public interface GuardUserService {
      */
     GuardUser getUser(String email) throws OXException;
 
+
+    /**
+     * Tries to retrieve the user associated with the given context- and user user-ID
+     *
+     * @param contextId The context-ID
+     * @param userId The user-ID
+     * @return The {@link GuardUser} if existing. Otherwise <code>null</code>.
+     * @throws OXException If an error occurs.
+     */
+    GuardUser getUser(int contextId, int userId) throws OXException;
+
     /**
      * Gets the guard capabilities for a given user.
      *
