@@ -52,6 +52,7 @@ package com.openexchange.guard.user.osgi;
 import org.slf4j.Logger;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.database.GuardDatabaseService;
+import com.openexchange.guard.email.storage.ogEmail.EmailStorage;
 import com.openexchange.guard.user.GuardUserService;
 import com.openexchange.guard.user.internal.GuardUserServiceImpl;
 import com.openexchange.guard.user.internal.Services;
@@ -70,7 +71,7 @@ public class GuardUserActivator extends HousekeepingActivator {
      */
     @Override
     protected Class<?>[] getNeededServices() {
-        return new Class<?>[] { GuardDatabaseService.class, GuardConfigurationService.class };
+        return new Class<?>[] { GuardDatabaseService.class, GuardConfigurationService.class, EmailStorage.class };
     }
 
     /**
@@ -81,7 +82,8 @@ public class GuardUserActivator extends HousekeepingActivator {
         Logger logger = org.slf4j.LoggerFactory.getLogger(GuardUserActivator.class);
         logger.info("Starting bundle: {}", context.getBundle().getSymbolicName());
         Services.setServiceLookup(this);
-        registerService(GuardUserService.class, new GuardUserServiceImpl(getService(GuardConfigurationService.class)));
+        registerService(GuardUserService.class,
+            new GuardUserServiceImpl(getService(GuardConfigurationService.class), getService(EmailStorage.class)));
         openTrackers();
         logger.info("GuardUserService registered.");
     }
