@@ -107,4 +107,13 @@ public interface GuardMaintenanceService {
 	 */
 	void resetGuest(String email, boolean force) throws OXException;
 
+    /**
+     * Changes a user's email, context or id, indentified by email address
+     * @param email
+     * @param newEmail
+     * @param newContext
+     * @param newUserId
+     */
+    void changeUser (String email, String newEmail) throws OXException;
+
 }
