@@ -61,15 +61,12 @@ import javax.mail.Part;
 import javax.mail.Session;
 import javax.mail.internet.MimeMessage;
 import javax.mail.internet.ParameterList;
-import javax.servlet.http.HttpServletResponse;
-
 import org.apache.commons.io.IOUtils;
 import org.apache.commons.lang.StringEscapeUtils;
 import org.apache.http.NameValuePair;
 import org.apache.http.client.utils.URLEncodedUtils;
 
 import com.openexchange.exception.OXException;
-import com.openexchange.guard.common.servlets.utils.ServletUtils;
 import com.openexchange.guard.exceptions.GuardAuthExceptionCodes;
 import com.openexchange.guard.internal.UserData;
 import com.openexchange.guard.mail.InlineImageHandler;
@@ -78,12 +75,8 @@ import com.openexchange.guard.oxapi.InlineImage;
 import com.openexchange.guard.oxapi.OxCookie;
 import com.openexchange.guard.pgp.PGPResult;
 import com.openexchange.guard.pgp.PGPUtils;
-import com.openexchange.guard.pgp.decryption.GuardEMailDecryptionService;
-import com.openexchange.guard.pgp.decryption.PGPDecryptionResult;
 import com.openexchange.guard.pgp.decryption.PGPMimeAttachmentExtractor;
-import com.openexchange.guard.pgp.decryption.impl.GuardEMailDecryptionServiceImpl;
 import com.openexchange.guard.pgp.exceptions.GuardPGPExceptionCodes;
-import com.openexchange.guard.pgp.exceptions.GuardPGPExceptionMessages;
 import com.openexchange.guard.storage.Storage;
 
 /**
@@ -140,7 +133,7 @@ public class GuestInlineImageHandler implements InlineImageHandler {
                 result = PGPUtils.decryptFile(in, guestData.getUserid(), guestData.getCid(), guestData.getEncr_password());
 
             } catch (OXException ex) {
-                if (ex.similarTo(GuardAuthExceptionCodes.BAD_PASSWORD)) {
+                if (GuardAuthExceptionCodes.BAD_PASSWORD.equals(ex)) {
                     in.close();
                     throw GuardPGPExceptionCodes.BAD_PASSWORD_ERROR.create();
                 } else {
