@@ -59,7 +59,7 @@ import java.util.concurrent.atomic.AtomicReference;
 import javax.servlet.http.Cookie;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
-
+import org.json.JSONObject;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -75,6 +75,7 @@ import com.openexchange.guard.cipher.GuardCipherAlgorithm;
 import com.openexchange.guard.cipher.GuardCipherFactoryService;
 import com.openexchange.guard.cipher.GuardCipherService;
 import com.openexchange.guard.common.java.Strings;
+import com.openexchange.guard.common.servlets.utils.AntiAbuseUtils;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
 import com.openexchange.guard.common.util.CipherUtil;
 import com.openexchange.guard.common.util.JsonUtil;
@@ -105,6 +106,7 @@ import com.openexchange.guard.oxapi.OxCookie;
 import com.openexchange.guard.ratifier.GuardRatifierService;
 import com.openexchange.guard.session.GuardSessionService;
 import com.openexchange.guard.translation.GuardTranslationService;
+import com.openexchange.guard.update.internal.GuardKeysUpdater;
 import com.openexchange.guard.user.GuardCapabilities;
 import com.openexchange.guard.user.GuardUserService;
 
@@ -158,7 +160,9 @@ public class Auth {
                     keyService.storeQuestion(userid, cid, "e", recEmail);
                 }
                 LOG.debug("Created master key for user");
-                response.getWriter().write(" {\"result\":\"ok\"} ");
+                JsonObject resp = new JsonObject();
+                resp.addProperty("result", "ok");
+                ServletUtils.sendJsonOK(response, resp);
             }
         } else {// Keys already exist, adding additional
             boolean adding = ServletUtils.getBooleanParameter(request, "add", false);
@@ -174,7 +178,9 @@ public class Auth {
                 keyService.updateSettingsForUser(keys);
                 keyService.updateAnswerQuestionForUser(keys);
                 LOG.info("Added additional key for user");
-                ServletUtils.sendHtmlOK(response, " {\"result\":\"ok\"} ");
+                JsonObject resp = new JsonObject();
+                resp.addProperty("result", "ok");
+                ServletUtils.sendJsonOK(response, resp);
             } else {
                 LOG.info("Fail creating key, already exists and add flag not set");
                 ServletUtils.sendNotAcceptable(response, "Existing");
@@ -209,7 +215,7 @@ public class Auth {
                     return;
                 }
             }
-            String newpass = JsonUtil.getStringFromJson(json, "newpass", true).trim();
+            String newpass = JsonUtil.getStringFromJson(json, "newpass", true);
             String question = "";
             if (json.has("question")) {// Sent with new question and answer?
                 question = json.get("question").getAsString();
@@ -257,21 +263,23 @@ public class Auth {
         final String newemail = new EmailValidator().assertInput(JsonUtil.getStringFromJson(json, "email", true), "email");
         GuardKeyService keyService = Services.getService(GuardKeyService.class);
 
-        if (antiabuse.blockLogin(userId, cid,  password, ServletUtils.getClientIP(request))) {
+        if (antiabuse.blockLogin(AntiAbuseUtils.getAllowParameters(request, userId, cid, password))) {
             ServletUtils.sendNotAcceptable(response, "Lockout");
             return;
         }
         GuardKeys keys = keyService.getKeys(userId, cid);
         if (PGPUtil.verifyPassword(keys.getPGPSecretKeyRing(), password, keys.getSalt())) {
             if (updateEmail(userId, cid, newemail)) {
-                ServletUtils.sendHtmlOK(response, "OK");
-                antiabuse.reportLogin(true, userId, cid, password, ServletUtils.getClientIP(request));
+                JSONObject resp = new JSONObject();
+                resp.put("data", "OK");
+                ServletUtils.sendHtmlOK(response, resp.toString());
+                antiabuse.report(AntiAbuseUtils.getReportParameter(true, request, userId,  cid, password));
             } else {
                 LOG.info("Problem updating secondary email");
                 ServletUtils.sendNotAcceptable(response, "Fail");
             }
         } else {
-            antiabuse.reportLogin(false, userId, cid, password, ServletUtils.getClientIP(request));
+            antiabuse.report(AntiAbuseUtils.getReportParameter(false, request, userId,  cid, password));
             LOG.info("Bad password for changing secondary email");
             ServletUtils.sendNotAcceptable(response, "Bad password");
             return;
@@ -284,9 +292,13 @@ public class Auth {
         List<GuardKeys> userKeys = ogKeyTableStorage.getKeysForUser(userid, cid);
         if (userKeys.size() > 0) {
             String encr_answer = userKeys.get(0).getAnswer();
+            String question = userKeys.get(0).getQuestion();
             if (encr_answer == null) {
                 return null;
             }
+            if (question == null || !question.equals("e")) {
+                return null;
+            }
             GuardCipherService cipherService = Services.getService(GuardCipherFactoryService.class).getCipherService(GuardCipherAlgorithm.AES_CBC);
             String rc = Services.getService(GuardMasterKeyService.class).getMasterKey().getRC();
             return cipherService.decrypt(encr_answer, rc, "e");
@@ -329,7 +341,9 @@ public class Auth {
 
         KeyTableStorage ogKeyTableStorage = Services.getService(KeyTableStorage.class);
         ogKeyTableStorage.deleteRecovery(key);
-        ServletUtils.sendHtmlOK(response, "OK");
+        JSONObject resp = new JSONObject();
+        resp.put("data", "OK");
+        ServletUtils.sendHtmlOK(response, resp.toString());
     }
 
     public void resetPass(int userid, int cid, HttpServletRequest request, HttpServletResponse response, OxCookie cookie, boolean web) throws Exception {
@@ -362,7 +376,8 @@ public class Auth {
             GuardRatifierService validatorService = Services.getService(GuardRatifierService.class);
             validatorService.validate(secondEmail);
             String hostname = (request == null ? "" : request.getServerName());
-            reset(userid, cid, response, web, templid, lang, userEmail, secondEmail, hostname);
+            String senderIp = (request == null ? null: request.getRemoteAddr());
+            reset(userid, cid, response, web, templid, lang, userEmail, secondEmail, hostname, senderIp);
 
             if (web) {
                 GuardAntiAbuseService antiabuse = Services.getService(GuardAntiAbuseService.class);
@@ -386,7 +401,7 @@ public class Auth {
         }
     }
 
-    protected void reset(int userid, int cid, HttpServletResponse response, boolean web, int templid, String lang, String userEmail, String secondEmail, String host) throws OXException {
+    protected void reset(int userid, int cid, HttpServletResponse response, boolean web, int templid, String lang, String userEmail, String secondEmail, String host, String senderIp) throws OXException {
         GuardKeyService keyService = Services.getService(GuardKeyService.class);
         boolean recoveryEnabled = keyService.isRecoveryEnabled(userid, cid);
         if (!recoveryEnabled) {
@@ -403,7 +418,7 @@ public class Auth {
         MailCreatorService mailCreatorService = Services.getService(MailCreatorService.class);
         GuardNotificationService guardNotificationService = Services.getService(GuardNotificationService.class);
         JsonObject mail = mailCreatorService.getResetEmail(secondEmail, mailCreatorService.getFromAddress(userEmail, userEmail, userid, cid), newpass, lang, templid, host, userid, cid);
-        guardNotificationService.send(mail);
+        guardNotificationService.send(mail, senderIp);
 
         keyService.resetPassword(userEmail, newpass);
     }
@@ -437,7 +452,7 @@ public class Auth {
             String password = JsonUtil.getStringFromJson(login_json, "password", true);
             GuardAntiAbuseService antiabuse = Services.getService(GuardAntiAbuseService.class);
             GuardConfigurationService configService = Services.getService(GuardConfigurationService.class);
-            if (antiabuse.blockLogin(username, password, ServletUtils.getClientIP(request))) {
+            if (antiabuse.blockLogin(AntiAbuseUtils.getAllowParameters(request, username, password))) {
                 response.getWriter().write("{\"auth\":\"lockout\", \"time:\": " + configService.getIntProperty(GuardProperty.badMinuteLock) + "}");
                 LOG.info("Guest auth lockout for " + username);
                 return;
@@ -473,7 +488,7 @@ public class Auth {
             if (password.equals("") && keys.getContextid() < 0) {
                 // Only works if recoveryAvail and configured to allow no password on first use
                 if (keys.isRecoveryAvail() && !configService.getBooleanProperty(GuardProperty.newGuestsRequirePassword)) {
-                    if (keys.getLastup() == null) {  // Make sure password never changed
+                    if (keys.getLastup() == null && (keys.getQuestion() == null || keys.getQuestion().equals("PIN"))) {  // Make sure password never changed
                         JsonObject sendjson = new JsonObject();
                         sendjson.addProperty("productName", GuardProductName.getProductName((request.getServerName())));
                         // If PIN
@@ -515,7 +530,7 @@ public class Auth {
             }
 
             if (!passwordVerified) {
-                antiabuse.reportLogin(false, username, password, ServletUtils.getClientIP(request));
+                antiabuse.report(AntiAbuseUtils.getReportParameter(false, request, username, password));
                 LOG.info("Bad password for " + username);
                 JsonObject sendjson = new JsonObject();
                 sendjson.addProperty("auth", returndata);
@@ -537,7 +552,7 @@ public class Auth {
                         returndata = "PIN";
                     }
                 } else {
-                    antiabuse.reportLogin(true, username, password, ServletUtils.getClientIP(request));
+                    antiabuse.report(AntiAbuseUtils.getReportParameter(true, request, username, password));
                     returndata = cipherService.encrypt(createAuthJson(json, keys.getUserid(), keys.getContextid(), keys.getEmail()).toString(), token);
                 }
             }
@@ -617,7 +632,7 @@ public class Auth {
         if (pubkey == null) {
             loadPublic();
         }
-        return pubkey.get();
+        return (pubkey == null ? null : pubkey.get());
     }
 
     public void login(JsonObject json, HttpServletRequest request, HttpServletResponse response, int userid, int cid, OxCookie cookie, GuardCapabilities settings) throws Exception {
@@ -642,8 +657,12 @@ public class Auth {
             if(email != null) {
                 email = new EmailValidator().assertInput(email, "email");
             }
+            String encrpass = JsonUtil.getStringFromJson(json, "encr_password");
+            if (encrpass == null) {
+                encrpass = "";
+            }
             // Check lockout of bad attempts.  If excessive, don't give encrypted auth key
-            if (antiabuse.blockLogin(userid, cid, "", ServletUtils.getClientIP(request))) {
+            if (antiabuse.blockLogin(AntiAbuseUtils.getAllowParameters(request, userid, cid, encrpass))) {
                 returnJson.addProperty("auth", "Lockout");
                 returnJson.add("settings", getSettings(null, settings, userid, cid));
                 ServletUtils.sendJsonOK(response, returnJson);
@@ -656,7 +675,7 @@ public class Auth {
                 ContextService contextService = Services.getService(ContextService.class);
                 contextService.getContext(cid);
             } catch (OXException ex) {
-                if (ex.similarTo(ContextExceptionCodes.UPDATE)) {
+                if (ContextExceptionCodes.UPDATE.equals(ex)) {
                     returnJson.addProperty("auth", "Updating");
                     returnJson.addProperty("error", ex.getDisplayMessage(new Locale(lang)));
                     ServletUtils.sendJsonOK(response, returnJson);
@@ -736,61 +755,33 @@ public class Auth {
 
             GuardCipherService cipherService = Services.getService(GuardCipherFactoryService.class).getCipherService(GuardCipherAlgorithm.AES_GCM);
             try {
-                String oxpassword = ((json == null) || (json.get("ox_password") == null)) ? "" : json.get("ox_password").getAsString();
-                if (oxpassword.equals("null")) {
-                    oxpassword = "";
-                }
-                String encrpass = JsonUtil.getStringFromJson(json, "encr_password");
-                if (encrpass == null) {
-                    encrpass = "";
-                }
                 String returndata = "Bad Password";
 
                 if (encrpass.length() > 1) {// If provided with encryption password, check
                     try {
-                        if (verifyPassword(keys, userid, cid, encrpass, request)) {
+                        VerificationResult passwordVerification = verifyPassword(keys, userid, cid, encrpass, request);
+                        if (passwordVerification.isValidated()) {
+                            GuardKeysUpdater updater = Services.getService(GuardKeysUpdater.class);
+                            if (updater != null) {
+                                updater.checkUpgrades(passwordVerification.getKey(), encrpass);
+                            }
                             returndata = cipherService.encrypt(createAuthJson(json, userid, cid, keys.getEmail()).toString(), token);
-                            antiabuse.reportLogin(true, userid, cid, encrpass, ServletUtils.getClientIP(request));
+                            antiabuse.report(AntiAbuseUtils.getReportParameter(true, request, userid,  cid, encrpass));
                             LOG.debug("Auth with proper password for cid = " + cid + " userid = " + userid);
                         } else {
-                            antiabuse.reportLogin(false, userid, cid, encrpass, ServletUtils.getClientIP(request));
+                            antiabuse.report(AntiAbuseUtils.getReportParameter(false, request, userid,  cid, encrpass));
                             LOG.debug("Auth, OG user, settings only for cid = " + cid + " userid = " + userid);
                         }
                     } catch (OXException e) {
-                        if (e.similarTo(GuardAuthExceptionCodes.LOCKOUT)) {
+                        if (GuardAuthExceptionCodes.LOCKOUT.equals(e)) {
                             returndata = "lockout";
                         }
-                        if (e.similarTo(GuardAuthExceptionCodes.BAD_PASSWORD)) {
-                            antiabuse.reportLogin(false, userid, cid, encrpass, ServletUtils.getClientIP(request));
+                        if (GuardAuthExceptionCodes.BAD_PASSWORD.equals(e)) {
+                            antiabuse.report(AntiAbuseUtils.getReportParameter(false, request, userid,  cid, encrpass));
                             LOG.debug("Auth, OG user, settings only for cid = " + cid + " userid = " + userid);
                         }
                     }
-                } else {// If no encr password, try the oxpassword
-                    if (oxpassword.length() > 1) {
-                        try {
-                            if (verifyPassword(keys, userid, cid, oxpassword, request)) {
-                                antiabuse.reportLogin(true, userid, cid, oxpassword, ServletUtils.getClientIP(request));
-                                json.remove("encr_password");
-                                json.addProperty("encr_password", oxpassword); // The encryption password is our ox password
-                                returndata = cipherService.encrypt(createAuthJson(json, userid, cid, keys.getEmail()).toString(), token);
-                                LOG.debug("Auth with proper password for cid = " + cid + " userid = " + userid);
-                                // returndata = encr.encryptAES(json.toString(), token, cookie.JSESSIONID, Config.AESKeyLen);
-                            } else {
-                                antiabuse.reportLogin(false, userid, cid, oxpassword, ServletUtils.getClientIP(request));
-                                LOG.debug("Auth, OG user, settings only for cid = " + cid + " userid = " + userid);
-                            }
-                        } catch (OXException e) {
-                            if (e.similarTo(GuardAuthExceptionCodes.LOCKOUT)) {
-                                returndata = "lockout";
-                            }
-                            if (e.similarTo(GuardAuthExceptionCodes.BAD_PASSWORD)) {
-                                antiabuse.reportLogin(false, userid, cid, oxpassword, ServletUtils.getClientIP(request));
-                                LOG.debug("Auth, OG user, settings only for cid = " + cid + " userid = " + userid);
-                            }
-                        }
-                    }
                 }
-
                 returnJson.addProperty("auth", returndata);
                 ServletUtils.sendJson(response, returnJson);
             } catch (Exception e) {
@@ -826,7 +817,6 @@ public class Auth {
      */
     private JsonObject createAuthJson(JsonObject json, int userid, int cid, String email) {
         JsonObject auth = new JsonObject();
-        auth.addProperty("ox_password", json.has("ox_password") ? json.get("ox_password").getAsString() : "");
         auth.addProperty("encr_password", json.has("encr_password") ? json.get("encr_password").getAsString() : "");
         auth.addProperty("email", email);
         auth.addProperty("user_id", userid);
@@ -862,23 +852,23 @@ public class Auth {
      * @return
      * @throws Exception
      */
-    private boolean verifyPassword(GuardKeys key, int userid, int cid, String password, HttpServletRequest request) throws Exception {
+    private VerificationResult verifyPassword(GuardKeys key, int userid, int cid, String password, HttpServletRequest request) throws Exception {
 
-        if (PGPUtil.verifyPassword(key.getPGPSecretKeyRing(), password, key.getSalt())) {
-            return (true);
+        if (key.getPGPSecretKeyRing() != null && PGPUtil.verifyPassword(key.getPGPSecretKeyRing(), password, key.getSalt())) {
+            return (new VerificationResult(key, true));
         }
         KeyTableStorage ogKeyTableStorage = Services.getService(KeyTableStorage.class);
         List<GuardKeys> userKeys = ogKeyTableStorage.getKeysForUser(userid, cid);
         if (userKeys.size() > 1) {
             for (GuardKeys userKey : userKeys) {
                 if (!userKey.isCurrent()) {// Don't recheck the current key
-                    if (PGPUtil.verifyPassword( userKey.getPGPSecretKeyRing(), password, userKey.getSalt())) {
-                        return (true);
+                    if (userKey.getPGPSecretKeyRing() != null && PGPUtil.verifyPassword( userKey.getPGPSecretKeyRing(), password, userKey.getSalt())) {
+                        return (new VerificationResult(userKey, true));
                     }
                 }
             }
         }
-        return (false);
+        return (new VerificationResult());
     }
 
     /**
