@@ -69,6 +69,7 @@ import com.openexchange.guard.oxapi.MailResolver;
 import com.openexchange.guard.ratifier.GuardRatifierService;
 import com.openexchange.guard.support.SupportService;
 import com.openexchange.guard.support.SupportServiceImpl;
+import com.openexchange.guard.support.UserChanger;
 
 /**
  * {@link GuardMaintenanceServiceImpl}
@@ -169,7 +170,7 @@ public class GuardMaintenanceServiceImpl implements GuardMaintenanceService {
         JsonObject mail = mailCreatorService.getResetEmail(email, mailCreatorService.getFromAddress(email, email, keys.getUserid(), keys.getContextid()), newpass, defaultLanguage, templid, "", 0, 0);
 
         GuardNotificationService guardNotificationService = Services.getService(GuardNotificationService.class);
-        guardNotificationService.send(mail);
+        guardNotificationService.send(mail, null);
 
         keyService.resetPassword(email, newpass);
     }
@@ -206,16 +207,27 @@ public class GuardMaintenanceServiceImpl implements GuardMaintenanceService {
 
     @Override
     public void delete(String email) throws OXException {
-    	GuardRatifierService validatorService = Services.getService(GuardRatifierService.class);
+        GuardRatifierService validatorService = Services.getService(GuardRatifierService.class);
         validatorService.validate(email);
-        	SupportService svc = new SupportServiceImpl();
-        	svc.deleteUser(email);
+            SupportService svc = new SupportServiceImpl();
+            svc.deleteUser(email);
     }
 
     @Override
     public void resetGuest(String email, boolean force) throws OXException {
         GuestResetService resetService = Services.getService(GuestResetService.class);
-        resetService.reset(email, 0, "", force, null);
+        GuardConfigurationService config = Services.getService(GuardConfigurationService.class);
+        resetService.reset(email, config.getIntProperty(GuardProperty.templateID), "", force, null);
+    }
+
+    /* (non-Javadoc)
+     * @see com.openexchange.guard.GuardMaintenanceService#changeUser(java.lang.String, java.lang.String, int, int)
+     */
+    @Override
+    public void changeUser(String email, String newEmail) throws OXException {
+        UserChanger changer = new UserChanger();
+        changer.changeUser(email, newEmail);
+
     }
 
 }
