@@ -68,7 +68,6 @@ public class UserData {
 
     private int cid;
 
-    private String ox_password;
 
     private String encr_password;
 
@@ -79,7 +78,7 @@ public class UserData {
     public UserData(String auth, OxCookie cookie) {
         long start = System.currentTimeMillis();
         userid = -1;
-        ox_password = encr_password = null;
+        encr_password = null;
         try {
             GuardSessionService sessionService = Services.getService(GuardSessionService.class);
             String token = sessionService.getToken(cookie.getJSESSIONID());
@@ -95,9 +94,6 @@ public class UserData {
             JsonObject userjson = gson.fromJson(userdata, JsonObject.class);
             userid = userjson.get("user_id").getAsInt();
             cid = userjson.get("cid").getAsInt();
-            if (userjson.get("ox_password") != null) {
-                ox_password = userjson.get("ox_password").getAsString();
-            }
             encr_password = userjson.get("encr_password").getAsString();
         } catch (Exception e) {
             LOG.error("Error creating user data for " + userid, e);
@@ -121,14 +117,6 @@ public class UserData {
         this.cid = cid;
     }
 
-    public String getOx_password() {
-        return ox_password;
-    }
-
-    public void setOx_password(String ox_password) {
-        this.ox_password = ox_password;
-    }
-
     public String getEncr_password() {
         return encr_password;
     }
