@@ -103,6 +103,8 @@ import com.openexchange.guard.keymanagement.services.GuardMasterKeyService;
 import com.openexchange.guard.keymanagement.services.RecipKeyService;
 import com.openexchange.guard.mail.exceptions.OXMailExceptionCodes;
 import com.openexchange.guard.mailcreator.MailCreatorService;
+import com.openexchange.guard.mime.services.Attachment;
+import com.openexchange.guard.mime.services.MimeParser;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.oxapi.Api;
 import com.openexchange.guard.oxapi.ApiResponse;
@@ -118,10 +120,10 @@ import com.openexchange.guard.pgp.decryption.GuardEMailDecryptionService;
 import com.openexchange.guard.pgp.decryption.PGPDecryptionResult;
 import com.openexchange.guard.pgp.decryption.impl.GuardEMailDecryptionServiceImpl;
 import com.openexchange.guard.pgpcore.services.TokenAuthenticationService;
-import com.openexchange.guard.pgpcore.services.UserIdentity;
 import com.openexchange.guard.ratifier.GuardRatifierService;
 import com.openexchange.guard.user.GuardCapabilities;
 import com.openexchange.guard.user.GuardUserService;
+import com.openexchange.guard.user.UserIdentity;
 import com.openexchange.guard.user.GuardCapabilities.Permissions;
 import com.openexchange.mail.usersetting.UserSettingMail;
 import com.openexchange.mail.usersetting.UserSettingMailStorage;
@@ -532,7 +534,7 @@ public class Incoming {
 
             PGPMail mail = new PGPMail(draft, draftFolder, json, attachments, attach_password, recipients, guestmessage, pin, templId, cookie, userid, cid, sessionId, inline, signit, userAgent);
             try {
-                String reply = new PGPSender().sendPGPMail(mail, request.getServerName());
+                String reply = new PGPSender().sendPGPMail(mail, request.getServerName(), request.getRemoteAddr());
                 if (reply != null)
                 {
                     if (JsonUtil.isJson(reply)) { // The reply will be either "OK" "Fail" or JSON Information
