@@ -64,7 +64,11 @@ import com.openexchange.exception.OXExceptionStrings;
 public enum OXMailExceptionCodes implements DisplayableOXExceptionCode {
 
     SEND_EMAIL_ERROR("Unable to send email to '%1$s'", OXMailExceptionMessages.SEND_EMAIL_ERROR, CATEGORY_ERROR, 1),
-
+    SEND_NOT_AUTHORIZED("User is not authorized to send Guard emails", OXMailExceptionMessages.SEND_NOT_AUTHORIZED, CATEGORY_ERROR, 2),
+    SEND_UNABLE_FIND_KEYS("Unable to find keys for all recipients", OXMailExceptionMessages.SEND_UNABLE_FIND_KEYS, CATEGORY_ERROR, 3),
+    NO_RECIPIENTS("Unable to encrypt, no recipients", CATEGORY_ERROR, 4),
+    UNKONWN_BODY_TYPE("Unable to encrypt due to unknown body type", CATEGORY_ERROR, 5),
+    UNKNOWN_EXCEPTION("Exception thrown '%1$s'", CATEGORY_ERROR, 6);
     ;
 
     private final String message;
