@@ -97,6 +97,7 @@ import com.openexchange.guard.keys.PGPKeyService;
 import com.openexchange.guard.mailcreator.MailCreatorService;
 import com.openexchange.guard.mailvelope.MailvelopeStorage;
 import com.openexchange.guard.mailvelope.internal.MailvelopeStorageImpl;
+import com.openexchange.guard.mime.services.MimeEncryptionService;
 import com.openexchange.guard.notification.GuardNotificationService;
 import com.openexchange.guard.oxapi.pooling.HttpConnectionPoolService;
 import com.openexchange.guard.pgpcore.services.PGPCryptoService;
@@ -111,7 +112,9 @@ import com.openexchange.guard.storage.cache.FileCacheStorage;
 import com.openexchange.guard.translation.GuardTranslationService;
 import com.openexchange.guard.update.GuardUpdateService;
 import com.openexchange.guard.user.GuardUserService;
+import com.openexchange.guard.update.internal.GuardKeysUpdater;
 import com.openexchange.osgi.HousekeepingActivator;
+import com.openexchange.pgp.keys.parsing.PGPKeyRingParser;
 import com.openexchange.startup.SignalHttpApiAvailabilityService;
 import com.openexchange.timer.TimerService;
 
@@ -142,7 +145,8 @@ public class GuardServiceActivator extends HousekeepingActivator {
             DeletedKeysStorage.class, Storage.class, GuardUpdateService.class, GuestUpgradeService.class, HKPClientService.class,
             PGPCryptoService.class, PGPSigningService.class, TokenAuthenticationService.class, FileCacheStorage.class, RemoteKeyCacheStorage.class,
             GuestResetService.class, TemporaryTokenService.class, KeyCreationService.class, GuardUserService.class, KeyRecoveryService.class,
-            PasswordChangeService.class, AccountCreationService.class, PublicExternalKeyService.class, KeyImportService.class, ContextService.class };
+            PasswordChangeService.class, AccountCreationService.class, PublicExternalKeyService.class, KeyImportService.class, ContextService.class,
+            MimeEncryptionService.class, PGPKeyRingParser.class, GuardKeysUpdater.class };
     }
 
     /*
