@@ -5,8 +5,8 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
 import java.util.ArrayList;
-import com.openexchange.guard.keys.dao.GuardKeys;
-import com.openexchange.guard.keys.dao.RecipKey;
+import com.openexchange.guard.keymanagement.commons.GuardKeys;
+import com.openexchange.guard.keymanagement.commons.RecipKey;
 import com.openexchange.guard.oxapi.streaming.StreamHandler;
 import com.openexchange.guard.pgp.PGPUtils;
 
