@@ -1,5 +1,10 @@
+
 package com.openexchange.guard.ox.streaming;
 
+import com.openexchange.exception.OXException;
+import com.openexchange.guard.encryption.exceptions.EncryptedItemsExceptionCodes;
+import com.openexchange.guard.oxapi.streaming.StreamHandler;
+
 /**
  * A simple factory for creation Stream handler based on a file's name / file's extension
  *
@@ -9,6 +14,7 @@ public class StreamHandlerFactory {
 
     /**
      * Creates a proper stream handler based on the given file name
+     *
      * @param fileName The file's name
      * @param userId The user's Id
      * @param cid CID
@@ -16,24 +22,15 @@ public class StreamHandlerFactory {
      * @param encryptedExtraPassword and optional, ecnrypted, password for the file
      * @param sessionId The session ID
      * @return A proper handler for encryption the file during streaming
+     * @throws OXException
      */
-    public static StreamHandler CreateStreamHandler(String fileName,
-                                                    int userId,
-                                                    int cid,
-                                                    String password,
-                                                    String encryptedExtraPassword,
-                                                    String sessionId) {
+    public static StreamHandler createStreamHandler(String fileName, int userId, int cid, String password, String sessionId) throws OXException {
         //in order to be backwards compatible to guard 1.0 and it's
         //own "guard" encryption mode we need to provide the possibility
         //to encrypt the old files encrypted with guard 1.0
-        if(fileName.endsWith(".grd") ||
-           fileName.endsWith(".grd2")) {
-            return new GuardStreamDecryptionHandler(userId,
-                cid,
-                password,
-                encryptedExtraPassword,
-                sessionId);
+        if (fileName.endsWith(".grd") || fileName.endsWith(".grd2")) {
+            throw EncryptedItemsExceptionCodes.NO_LONGER_SUPPORTED.create();
         }
         return new PGPStreamDecryptionHandler(userId, cid, password);
     }
-}
\ No newline at end of file
+}
