@@ -66,6 +66,7 @@ import org.apache.commons.io.IOUtils;
 import org.bouncycastle.openpgp.PGPPrivateKey;
 import org.bouncycastle.openpgp.PGPPublicKey;
 import org.bouncycastle.openpgp.PGPPublicKeyRing;
+import org.json.JSONObject;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import com.google.gson.JsonElement;
@@ -222,9 +223,11 @@ public class PGPPrivateKeyHandler {
                 } else {
                     GuardKeys existing = PGPPublicHandler.getKeyForPGP(userid, cid, dupl, true);
 
-                    if (!PGPUtil.verifyPassword(existing.getPGPSecretKeyRing(), password, existing.getSalt())) {
-                        ServletUtils.sendNotAcceptable(response, "Bad Merge Password");
-                        return;
+                    if (existing.getPGPSecretKeyRing() != null) {
+                        if (password == null || !PGPUtil.verifyPassword(existing.getPGPSecretKeyRing(), password, existing.getSalt())) {
+                            ServletUtils.sendNotAcceptable(response, "Bad Merge Password");
+                            return;
+                        }
                     }
 
                     //////////// HANDLE MERGE/DUPLICATE public keys
@@ -405,8 +408,9 @@ public class PGPPrivateKeyHandler {
             EmailStorage ogEmailStorage = Services.getService(EmailStorage.class);
             ogEmailStorage.deleteAllForUser(cid, userid);
         }
-
-        ServletUtils.sendHtmlOK(response, "OK");
+        JSONObject resp = new JSONObject();
+        resp.put("data", "ok");
+        ServletUtils.sendHtmlOK(response, resp.toString());
         LOG.debug("Success deleting private key");
 
     }
@@ -475,8 +479,9 @@ public class PGPPrivateKeyHandler {
 
         KeyTableStorage keyTableStorage = Services.getService(KeyTableStorage.class);
         keyTableStorage.updatePublicKey(key);
-
-        ServletUtils.sendHtmlOK(response, "OK");
+        JSONObject resp = new JSONObject();
+        resp.put("data", "OK");
+        ServletUtils.sendHtmlOK(response, resp.toString());
         LOG.info("Success deleting private key");
 
     }
@@ -539,6 +544,9 @@ public class PGPPrivateKeyHandler {
             EmailStorage ogEmailStorage = Services.getService(EmailStorage.class);
             ogEmailStorage.deleteAllForUser(cid, userid);
         }
+        JsonObject resp = new JsonObject();
+        json.addProperty("data", "ok");
+        ServletUtils.sendJsonOK(response, resp);
 
     }
 
@@ -597,7 +605,9 @@ public class PGPPrivateKeyHandler {
         }
         keys.setPGPPublicKeyRing(newring);
         pgpKeyService.updatePGPKeys(userid, cid, keys);
-        ServletUtils.sendHtmlOK(response, "OK");
+        JSONObject resp = new JSONObject();
+        resp.put("data", "OK");
+        ServletUtils.sendHtmlOK(response, resp.toString());
     }
 
 }
