@@ -81,17 +81,16 @@ import com.openexchange.guard.common.util.IDNUtil;
 import com.openexchange.guard.common.util.ListUtil;
 import com.openexchange.guard.common.util.LongUtil;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
+import com.openexchange.guard.internal.UserData;
 import com.openexchange.guard.keymanagement.commons.GuardKeys;
 import com.openexchange.guard.keymanagement.commons.OGPGPKey;
 import com.openexchange.guard.keymanagement.commons.PGPKeys;
 import com.openexchange.guard.keymanagement.commons.export.KeyExportUtil;
-import com.openexchange.guard.keymanagement.commons.parsing.AsciiArmoredKeyParser;
-import com.openexchange.guard.keymanagement.commons.parsing.PGPPublicKeyRingFactory;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.keymanagement.storage.OGPGPKeysStorage;
 import com.openexchange.guard.keymanagement.storage.PGPKeysStorage;
 import com.openexchange.guard.keys.PGPKeyService;
-import com.openexchange.guard.mail.Attachment;
+import com.openexchange.guard.mime.services.Attachment;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.oxapi.Api;
 import com.openexchange.guard.oxapi.ApiResponse;
@@ -100,6 +99,9 @@ import com.openexchange.guard.pgp.decryption.GuardEMailDecryptionService;
 import com.openexchange.guard.pgp.decryption.PGPDecryptionResult;
 import com.openexchange.guard.pgp.decryption.impl.GuardEMailDecryptionServiceImpl;
 import com.openexchange.guard.ratifier.GuardRatifierService;
+import com.openexchange.pgp.keys.parsing.KeyRingParserResult;
+import com.openexchange.pgp.keys.parsing.PGPKeyRingParser;
+import com.openexchange.pgp.keys.parsing.PGPPublicKeyRingFactory;
 
 public class PGPPublicHandler {
 
@@ -132,9 +134,14 @@ public class PGPPublicHandler {
             }
 
             //Parsing the input stream for public keys rings and using the factory to create them
-            List<PGPPublicKeyRing> publicKeys = PGPPublicKeyRingFactory.create(new AsciiArmoredKeyParser().parse(fi.getInputStream()));
+            List<PGPPublicKeyRing> publicKeys = null;
+            PGPKeyRingParser keyParser = Services.getService(PGPKeyRingParser.class);
+            KeyRingParserResult parseResult = keyParser.parse(fi.getInputStream());
+            if(parseResult != null) {
+                publicKeys = parseResult.toPublicKeyRings();
+            }
 
-            if (publicKeys.size() > 0) {
+            if (publicKeys != null && publicKeys.size() > 0) {
                 //If the client provided an email filter we only consider parsed public keys which userids are in the filter
                 String[] emails = emailRestriction == null ? null : emailRestriction.split(",");
                 if (emails != null) {
@@ -275,9 +282,9 @@ public class PGPPublicHandler {
             return;
         }
         PGPPublicKeyRing ring = null;
-        String epass = ServletUtils.getStringParameter(request, "epass");
+        String auth = ServletUtils.getStringParameter(request, "auth");
         String data = null;
-        if (epass == null) {  // If not encrypted, retrieve plaintext
+        if (auth == null) {  // If not encrypted, retrieve plaintext
             try(ApiResponse plainAttachment = ap.getPlainAttachment(emailid, attach, folder)){
                 Attachment att = new Attachment();
                 att.setContent(plainAttachment.readContent());
@@ -287,8 +294,8 @@ public class PGPPublicHandler {
             // Handle encrypted public key
             String filename = ServletUtils.getStringParameter(request, "filename", true);
             boolean inline = ServletUtils.getBooleanParameter(request, "inline",false);
-            String jSessionId = ck.getJSESSIONID();
-            String password = PGPUtils.decodeEPass(epass, jSessionId);
+            UserData userdata = new UserData(auth, ck);
+            String password = userdata.getEncr_password();
             if (password == null) {
                 ServletUtils.sendNotAcceptable(response, "bad password");
                 return;
