@@ -53,9 +53,9 @@ import com.openexchange.guard.encryption.EncryptedItemsStorage;
 import com.openexchange.guard.keymanagement.commons.GuardKeys;
 import com.openexchange.guard.keymanagement.commons.RecipKey;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
-import com.openexchange.guard.mail.Attachment;
 import com.openexchange.guard.mail.GuardMimeMessage;
 import com.openexchange.guard.mailcreator.MailCreatorService;
+import com.openexchange.guard.mime.services.Attachment;
 import com.openexchange.guard.notification.GuardNotificationService;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.oxapi.Api;
@@ -76,7 +76,7 @@ public class PGPSender {
      * @throws OXException
      * @throws Exception
      */
-    public String sendPGPMail(PGPMail mail, String host) throws OXException {
+    public String sendPGPMail(PGPMail mail, String host, String remoteIp) throws OXException {
         boolean lInline = mail.isInline();
 
         GuardKeyService keyService = Services.getService(GuardKeyService.class);
@@ -99,14 +99,14 @@ public class PGPSender {
         mail.getRecipients().add(sender);
 
         if (lInline && !mail.isDraft()) {  // Drafts will be saved as PGP Mime
-            sendPGPInline(mail, senderkey, host);
+            sendPGPInline(mail, senderkey, host, remoteIp);
         } else {
-            return sendPGPMime(mail, mail.getRecipients(), senderkey, host);
+            return sendPGPMime(mail, mail.getRecipients(), senderkey, host, remoteIp);
         }
         return null;
     }
 
-    private void sendPGPInline(PGPMail mail, GuardKeys senderkey, String host) throws OXException {
+    private void sendPGPInline(PGPMail mail, GuardKeys senderkey, String host, String remoteIp) throws OXException {
         List<RecipKey> guestRecip = new ArrayList<RecipKey>();
         List<RecipKey> inlineRecip = new ArrayList<RecipKey>();
         RecipKey sender = new RecipKey();
@@ -129,7 +129,7 @@ public class PGPSender {
         // Send guest emails (these are PGP Mime)
         if (guestRecip.size() > 0) {
             guestRecip.add(sender);
-            sendPGPMime(mail, guestRecip, senderkey, host);
+            sendPGPMime(mail, guestRecip, senderkey, host, remoteIp);
             // If we have sent some of the emails to a guest, then we need to remove them for the inline emails and mark the headers
             updateJsonRecip(mail, inlineRecip);
         }
@@ -174,7 +174,7 @@ public class PGPSender {
                 JsonArray fromarray = data.get("from").getAsJsonArray().get(0).getAsJsonArray();
                 GuardNotificationService guardNotificationService = Services.getService(GuardNotificationService.class);
                 List<BodyPart> bpAttachments = getBodyParts(attachments);
-                guardNotificationService.send(content, bpAttachments, getFromEmailAddress(recipients, fromarray.get(1).getAsString()), sender.getLang(), getMessageID());
+                guardNotificationService.send(content, bpAttachments, getFromEmailAddress(recipients, fromarray.get(1).getAsString()), senderkey.getContextid(), sender.getLang(), getMessageID(), remoteIp);
             }
         }
     }
@@ -245,7 +245,7 @@ public class PGPSender {
         return toString.toString();
     }
 
-    private String sendPGPMime(PGPMail mail, List<RecipKey> guestRecip, GuardKeys senderkey, String host) throws OXException {
+    private String sendPGPMime(PGPMail mail, List<RecipKey> guestRecip, GuardKeys senderkey, String host, String remoteIp) throws OXException {
         byte[] mime = null;
         String messageId = getMessageID();
         try {
@@ -266,7 +266,7 @@ public class PGPSender {
             } else {
                 PGPUtils.encrypt(encrypted, mime, "encrypted.asc", guestRecip, true, true);
             }
-            String resp = sendMimeEmails(mail, guestRecip, encrypted, messageId, host, senderkey.getUserid(), senderkey.getContextid());
+            String resp = sendMimeEmails(mail, guestRecip, encrypted, messageId, host, senderkey.getUserid(), senderkey.getContextid(), remoteIp);
             if (Utilities.checkFail(resp) || !resp.contains("fail")) {
                 handleFlags(mail);
             } else {
@@ -325,7 +325,7 @@ public class PGPSender {
      * @return
      * @throws MessagingException
      */
-    private String sendMimeEmails(PGPMail mail, List<RecipKey> guestRecip, ByteArrayOutputStream encrypted, String messageId, String host, int senderId, int senderCid) throws Exception {
+    private String sendMimeEmails(PGPMail mail, List<RecipKey> guestRecip, ByteArrayOutputStream encrypted, String messageId, String host, int senderId, int senderCid, String remoteIp) throws Exception {
         JsonObject data = mail.getContent().getAsJsonObject("data");
         List<String> failures = new ArrayList<String>();
         Api ap = new Api(mail.getOXCookie(), mail.getSession(), mail.getUseragent());
@@ -346,8 +346,11 @@ public class PGPSender {
             LOG.error("Problem extracting headers");
         }
 
+        GuardConfigurationService guardConfigService = Services.getService(GuardConfigurationService.class);
+
+        boolean addHelpFiles = guardConfigService.getBooleanProperty(GuardProperty.attachHelpFile, mail.getUserid(), mail.getCid());
         GuardMimeMessage newMessage = new GuardMimeMessage(Session.getInstance(new Properties()), messageId);
-        newMessage.setContent(new PGPMailCreator().getPGPMime(encrypted.toByteArray(), getLanguages(guestRecip)));
+        newMessage.setContent(new GuardPGPMimeMailCreator().createPGPMime(encrypted.toByteArray(), addHelpFiles ? getLanguages(guestRecip) : null));
 
         String uid = CipherUtil.getUUID();
         String id = "pgp-" + uid;
@@ -390,7 +393,6 @@ public class PGPSender {
                         } catch (Exception ex) {
                             LOG.error("Problem adding guest header", ex);
                         }
-                        GuardConfigurationService guardConfigService = Services.getService(GuardConfigurationService.class);
                         try {
                             String url = guardConfigService.getProperty(GuardProperty.externalReaderURL, mail.getUserid(), mail.getCid());
                             if (url == null || url.isEmpty()) {
@@ -434,7 +436,7 @@ public class PGPSender {
                             GuardNotificationService guardNotificationService = Services.getService(GuardNotificationService.class);
                             List<BodyPart> bpAttachments = getBodyParts(attachments);
                             try {
-                                guardNotificationService.send(email, bpAttachments, getFromEmailAddress(guestRecip, fromEmail), recip.getLang(), messageId);
+                                guardNotificationService.send(email, bpAttachments, getFromEmailAddress(guestRecip, fromEmail), senderCid, recip.getLang(), messageId, remoteIp);
                             } catch (OXException e) {
                                 return "fail";
                             }
@@ -507,7 +509,7 @@ public class PGPSender {
             } else { // Otherwise, use the SMTP service
                 GuardNotificationService guardNotificationService = Services.getService(GuardNotificationService.class);
                 try {
-                    guardNotificationService.sendMessage(newMessage, getFromEmailAddress(guestRecip, fromaddr.getAddress()), guestRecip.get(0).getLang());
+                    guardNotificationService.sendMessage(newMessage, getFromEmailAddress(guestRecip, fromaddr.getAddress()), senderCid, guestRecip.get(0).getLang(), remoteIp);
                 } catch (OXException e) {
                     return "fail";
                 }
