@@ -58,6 +58,7 @@ import java.nio.charset.StandardCharsets;
 import java.security.NoSuchProviderException;
 import java.security.SecureRandom;
 import java.security.SignatureException;
+import java.util.ArrayList;
 import java.util.Date;
 import java.util.Iterator;
 import java.util.List;
@@ -106,7 +107,10 @@ import com.openexchange.guard.keymanagement.commons.RecipKey;
 import com.openexchange.guard.keys.PGPKeyService;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.pgp.exceptions.GuardPGPExceptionCodes;
+import com.openexchange.guard.pgpcore.services.FromHeaderVerifier;
 import com.openexchange.guard.session.GuardSessionService;
+import com.openexchange.pgp.core.PGPSignatureVerificationResult;
+import com.openexchange.pgp.keys.tools.PGPKeysUtil;
 
 public class PGPUtils {
 
@@ -319,6 +323,43 @@ public class PGPUtils {
         return result;
     }
 
+    /**
+     * Verify the from address is in the list of userIds for the public keys
+     * @param result
+     * @param keyring
+     * @param fromAddress
+     * @return
+     */
+    private PGPResult verifyFrom(PGPResult result, PGPPublicKeyRing keyring, String fromAddress) {
+        if (!result.isVerified()) {
+            return result;
+        }
+        if (fromAddress == null || fromAddress.isEmpty()) {
+            result.setVerified(false);
+            result.setError("Unable to verify due to missing FROM address");
+            return result;
+        }
+        ArrayList<String> userIds = new ArrayList<String>();
+        Iterator<PGPPublicKey> keys = keyring.getPublicKeys();
+        while (keys.hasNext()) {
+            PGPPublicKey key = (PGPPublicKey) keys.next();
+            Iterator ids = key.getUserIDs();
+            while (ids.hasNext()) {
+                userIds.add((String) ids.next());
+            }
+        }
+        Iterator ids = userIds.iterator();
+        while (ids.hasNext()) {
+            String id = (String) ids.next();
+            if (id.toLowerCase().contains(fromAddress.toLowerCase())) return result;
+
+        }
+        result.setVerified(false);
+        result.setError("The issuer of the signature was not found in the FROM header for the MIME message.");
+        return result;
+
+    }
+
     /**
      * Verify signature in inline signature
      *
@@ -339,7 +380,22 @@ public class PGPUtils {
 
         PGPObjectFactory pgpF = new PGPObjectFactory(in, new BcKeyFingerprintCalculator());
 
-        Object o = pgpF.nextObject();
+        Object o = null;
+        try {
+            o = pgpF.nextObject();
+        } catch (IOException ex) {
+            // If next object is a signature, and we simply don't know the algorithm, don't fail
+            // Ignore signature for now
+            if (ex.getMessage() != null && ex.getMessage().contains("unknown signature key algorithm")) {
+                LOG.info("Unkown signature key algorithm");
+                result.setError("Unknown algorithm");
+                result.setVerified(false);
+                result.setMissingPublicKey(true);
+                return (result);
+            } else {
+                throw ex;
+            }
+        }
         if (o == null) {
             result.setError("No Encrypted items");
             return (result);
@@ -370,12 +426,13 @@ public class PGPUtils {
             } else {
                 result.setVerified(false);
             }
+            result = verifyFrom(result, pgpRing, fromAddress);
 
         } else {
             result.setSignature(false);
             // no signature
         }
-        return (result);
+        return result;
     }
 
     /**
@@ -397,7 +454,22 @@ public class PGPUtils {
         InputStream in = PGPUtil.getDecoderStream(datastream);
         PGPObjectFactory factory = new PGPObjectFactory(in, new BcKeyFingerprintCalculator());
         PGPSignatureList list = null;
-        Object o = factory.nextObject();
+        Object o = null;
+        try {
+            o = factory.nextObject();
+        } catch (IOException ex) {
+            // If next object is a signature, and we simply don't know the algorithm, don't fail
+            // Ignore signature for now
+            if (ex.getMessage() != null && ex.getMessage().contains("unknown signature key algorithm")) {
+                LOG.info("Unkown signature key algorithm");
+                result.setError("Unknown algorithm");
+                result.setVerified(false);
+                result.setMissingPublicKey(true);
+                return (result);
+            } else {
+                throw ex;
+            }
+        }
         if (o == null) {
             LOG.error("No signature found");
             result.setError("No signature found");
@@ -444,7 +516,7 @@ public class PGPUtils {
             result.setMissingPublicKey(true);
             return (result);
         }
-        sig.init(new JcaPGPContentVerifierBuilderProvider(), key);
+        sig.init(new JcaPGPContentVerifierBuilderProvider().setProvider("BC"), key);
         while ((ch = sigfile.read()) >= 0) {
             sig.update((byte) ch);
         }
@@ -456,7 +528,7 @@ public class PGPUtils {
         } else {
             result.setVerified(false);
         }
-        return (result);
+        return (verifyFrom(result, pgpRing, fromAddress));
 
     }
 
@@ -561,14 +633,14 @@ public class PGPUtils {
         Iterator it = ring.getPublicKeys();
         while (it.hasNext()) {
             PGPPublicKey key = (PGPPublicKey) it.next();
-            if (com.openexchange.guard.keymanagement.commons.util.PGPUtil.isEncryptionKey(key)) {
-                if (key.isMasterKey() && !com.openexchange.guard.keymanagement.commons.util.PGPUtil.isExpired(key) && !key.hasRevocation()) {  // If master key, we will use only if we don't have another encryption key
+            if (PGPKeysUtil.isEncryptionKey(key)) {
+                if (key.isMasterKey() && !PGPKeysUtil.isExpired(key) && !key.hasRevocation()) {  // If master key, we will use only if we don't have another encryption key
                     if (found == null) {
                         found = key;
                     }
                 } else {
                     if (!key.hasRevocation()) {
-                        if (!com.openexchange.guard.keymanagement.commons.util.PGPUtil.isExpired(key)) {
+                        if (!PGPKeysUtil.isExpired(key)) {
                             return (key);
                         }
                     }
@@ -629,7 +701,7 @@ public class PGPUtils {
         builder.setWithIntegrityPacket(true);
         PGPEncryptedDataGenerator encryptedDataGenerator = new PGPEncryptedDataGenerator(builder);
         for (int i = 0; i < recipients.size(); i++) {
-            BcPublicKeyKeyEncryptionMethodGenerator encKeyGen = new BcPublicKeyKeyEncryptionMethodGenerator(getCryptKey(recipients.get(i).getPGPPublicKeyRing()));
+            BcPublicKeyKeyEncryptionMethodGenerator encKeyGen = new BcPublicKeyKeyEncryptionMethodGenerator(recipients.get(i).getEncryptionKey());
             encryptedDataGenerator.addMethod(encKeyGen);
         }
         OutputStream encryptedOut = encryptedDataGenerator.open(out, new byte[4028]);
@@ -680,7 +752,7 @@ public class PGPUtils {
             out = new ArmoredOutputStream(out);
         }
 
-        int algorithm = com.openexchange.guard.keymanagement.commons.util.PGPUtil.getSigningKey(key.getPGPSecretKeyRing()).getPublicKey().getAlgorithm();
+        int algorithm = PGPKeysUtil.getSigningKey(key.getPGPSecretKeyRing()).getPublicKey().getAlgorithm();
         PGPSignatureGenerator sgen = new PGPSignatureGenerator(new JcaPGPContentSignerBuilder(algorithm, PGPUtil.SHA512).setProvider("BC"));
         PGPKeyService pgpKeyService = Services.getService(PGPKeyService.class);
         PGPPrivateKey pgpSignKey;
