@@ -78,13 +78,13 @@ public abstract class AbstractGuardServlet extends HttpServlet {
      * Initializes a new {@link AbstractGuardServlet}.
      */
     public AbstractGuardServlet() {
-        //Default OXException errors will be sent as SC_OK according to the OX HTTP API 
+        //Default OXException errors will be sent as SC_OK according to the OX HTTP API
         errorResponseRenderer = new GuardErrorResponseRenderer(HttpServletResponse.SC_OK);
     }
 
     /**
      * Initializes a new {@link AbstractGuardServlet}.
-     * 
+     *
      * @param errorResponseRenderer The error renderer to use in case of an OXException
      */
     public AbstractGuardServlet(GuardErrorResponseRenderer errorResponseRenderer) {
@@ -130,7 +130,11 @@ public abstract class AbstractGuardServlet extends HttpServlet {
             //Creating error object for the client
             LOG.error(String.format("Error processing command \"%s\": %s", actionName, e.getMessage()), e);
             try {
-                errorResponseRenderer.renderError(request, response, actionName, e);
+                GuardErrorResponseRenderer errorRenderer = action.getErrorResponseRenderer();
+                if(errorRenderer == null) {
+                    errorRenderer = this.errorResponseRenderer;
+                }
+                errorRenderer.renderError(request, response, actionName, e);
             } catch (IOException e1) {
                 LOG.error(String.format("Error writing response: %s", e.getMessage()), e1);
                 ServletUtils.sendError(response, e.getMessage());
