@@ -15,20 +15,23 @@ public class GuardUserSession {
     private final int userId;
     private final int contextId;
     private final Locale locale;
+    private final ConnectionInformation connectionInformation;
 
     /**
      * Initializes a new {@link GuardUserSession}.
-     * 
+     *
      * @param sessionId the Appsuite session id or a guard guest session ID
      * @param contextId the context id
      * @param userId the user id
      * @param locale The user's locale
+     * @param connectionInformation {@link ConnectionInformation}for the session
      */
-    public GuardUserSession(String sessionId, int contextId, int userId, Locale locale) {
+    public GuardUserSession(String sessionId, int contextId, int userId, Locale locale, ConnectionInformation connectionInformation) {
         this.sessionId = sessionId;
         this.userId = userId;
         this.contextId = contextId;
         this.locale = locale;
+        this.connectionInformation = connectionInformation;
     }
 
     /**
@@ -59,4 +62,11 @@ public class GuardUserSession {
         return locale;
     }
 
+    /**
+     * @return the session's {@link ConnectionInformation}
+     */
+    public ConnectionInformation getConnectionInformation() {
+        return connectionInformation;
+    }
+
 }
