@@ -109,11 +109,11 @@ public class GuestSessionValidator implements SessionValidator {
                         if (userDataJson.has("user_id") && userDataJson.has("cid")) {
                             int userId = userDataJson.get("user_id").getAsInt();
                             int contextId = userDataJson.get("cid").getAsInt();
-                            if (contextId < 0) {
+                            //if (contextId < 0) {   // This check removed for bug 56873, was interfering after upgarde to full OX account
                                 //Guest sessions do always have negative context-id
                                 GuardUserSession guardUserSession = new GuardUserSession(guestSessionId, contextId, userId, getLocaleFor(request),createConnectionInformationFrom(request));
                                 return guardUserSession;
-                            }
+                            //}
                         }
                     }
                 }
