@@ -7,8 +7,8 @@ import com.openexchange.exception.OXException;
 import com.openexchange.guard.oxapi.Api;
 import com.openexchange.guard.oxapi.OxCookie;
 import com.openexchange.guard.oxapi.SessionInformation;
-import static com.openexchange.guard.servlets.util.UserLocaleUtil.*;
-
+import static com.openexchange.guard.servlets.util.ServletLocaleUtil.*;
+import static com.openexchange.guard.servlets.authentication.ConnectionInformationFactory.*;
 
 /**
  * {@link RestSessionValidator} Validates the sessionID using the OX Rest API
@@ -21,7 +21,7 @@ public class RestSessionValidator implements SessionValidator {
     private static final String JSON_CONTEXT = "context";
     private static final String JSON_USER = "user";
     private static final String[] SESSION_PARAMETER_NAMES = { "session" };
-    
+
     private String getSession(HttpServletRequest request) {
 
         //Getting session from parameter
@@ -31,11 +31,9 @@ public class RestSessionValidator implements SessionValidator {
                 return session;
             }
         }
-
-        //..or as fallback from the cookie
-        return new OxCookie(request.getCookies()).getSessionID();
+        return null;
     }
-        
+
     @Override
     public
     GuardUserSession validateSession(HttpServletRequest request) throws OXException {
@@ -43,12 +41,12 @@ public class RestSessionValidator implements SessionValidator {
         String sessionId = getSession(request);
         String userAgent = request.getHeader("User-Agent");
         if (sessionId != null && !sessionId.isEmpty()) {
-            //Checking if session is valid 
+            //Checking if session is valid
             if(new Api(new OxCookie(request.getCookies()),sessionId,userAgent).verifyLogin()) {
                 //Getting user-id and context-id from session - instead of trusting client input
                 JsonObject sessionObject = new SessionInformation().getSessionInformation(sessionId);
                 if (sessionObject != null && sessionObject.has(JSON_CONTEXT) && sessionObject.has(JSON_USER)) {
-                    return new GuardUserSession(sessionId, sessionObject.get(JSON_CONTEXT).getAsInt(), sessionObject.get(JSON_USER).getAsInt(), getLocaleFor(request));
+                    return new GuardUserSession(sessionId, sessionObject.get(JSON_CONTEXT).getAsInt(), sessionObject.get(JSON_USER).getAsInt(), getLocaleFor(request), createConnectionInformationFrom(request));
                 }
             }
         }
