@@ -76,8 +76,10 @@ public class CallbackServlet extends AbstractGuardServlet {
 
     private static final long serialVersionUID = 6518623347823371079L;
     private static final String PUT_USERDELETED_CALLBACK_ACTION = "user_delete";
+    private static final String PUT_USER_CHANGED = "user_update";
     private static final String PUT_CONTEXTDELETED_CALLBACK_ACTION = "context_delete";
     private static final String POST_PROCESS_MESSAGE = "process_message";
+    private static final String POST_ENCRYPT_MESSAGE = "process_mime";
     private static final String GET_ATTACHMENT_ACTION = "getattach";
     private static final String GET_INLINE_ATTACHMENT_ACTION = "getinlineattach";
 
@@ -106,13 +108,11 @@ public class CallbackServlet extends AbstractGuardServlet {
             //PUT
             putActions.put(PUT_USERDELETED_CALLBACK_ACTION, new UserDeletedCallbackAction().setAuthenticationHandler(basicAuthServletAuthentication));
             putActions.put(PUT_CONTEXTDELETED_CALLBACK_ACTION, new ContextDeletedCallbackAction().setAuthenticationHandler(basicAuthServletAuthentication));
+            putActions.put(PUT_USER_CHANGED, new UserUpdateCallbackAction().setAuthenticationHandler(basicAuthServletAuthentication));
 
             //GET - This actions are used to retrieval documents for the OX Documentconverter
             getActions.put(GET_ATTACHMENT_ACTION, new GetAttachmentByNameAction().setAuthenticationHandler(basicAuthServletAuthentication));
             getActions.put(GET_INLINE_ATTACHMENT_ACTION, new GetInlineAttachmentAction().setAuthenticationHandler(basicAuthServletAuthentication));
-
-            //POST
-            postActions.put(POST_PROCESS_MESSAGE, new SignEmailAction().setAuthenticationHandler(basicAuthServletAuthentication));
         }
         else{
             logger.error("Denied OX Guard callback servlet initialization due to unset Basic-Auth configuration. Please set properties 'com.openexchangeguard.restApiUsername' and 'com.openexchangeguard.restApiPassword' appropriately.");
