@@ -141,7 +141,7 @@ public class Guest {
         }
         String email = "";
         if (json.has("email")) {
-        	email = new EmailValidator().assertInput(json.get("email").getAsString());
+            email = new EmailValidator().assertInput(json.get("email").getAsString());
             answer = json.get("email").getAsString();
             if (!answer.equals("")) {
                 question = "e";
@@ -201,7 +201,7 @@ public class Guest {
                         result = PGPUtils.decryptFile(in, data.getUserid(), data.getCid(), data.getEncr_password());
 
                     } catch (OXException ex) {
-                        if (ex.similarTo(GuardAuthExceptionCodes.BAD_PASSWORD) || ex.similarTo(GuardPGPExceptionCodes.BAD_PASSWORD_ERROR)) {
+                        if (GuardAuthExceptionCodes.BAD_PASSWORD.equals(ex) || GuardPGPExceptionCodes.BAD_PASSWORD_ERROR.equals(ex)) {
                             in.close();
                             ServletUtils.sendNotAcceptable(response, "Bad password");
                             return;
@@ -294,9 +294,13 @@ public class Guest {
         JsonObject data = new JsonObject();
         InputStream in = new ByteArrayInputStream(result.getDecoded());
         MimeMessage message = new MimeMessage(s, in);
-        Multipart mp = (Multipart) message.getContent();
+        Object content = message.getContent();
         JsonArray attachments = new JsonArray();
-        DecryptedMailResponseFactory.ParseMultipart(mp, attachments);
+        if (content instanceof String) {
+            DecryptedMailResponseFactory.ParseStringBody((String) content, attachments);  // Plaintext only message
+        } else {
+            DecryptedMailResponseFactory.ParseMultipart((Multipart) content, attachments); // Multipart message
+        }
         JsonObject Results = new JsonObject();
         Results.add("signature", new JsonPrimitive(result.isSignature()));
         Results.add("verified", new JsonPrimitive(result.isVerified()));
@@ -493,7 +497,8 @@ public class Guest {
                     return;
                 }
             }
-            reset(email, lang, templId, cid, userid, request.getServerName());
+            String senderIp = (request == null ? null: request.getRemoteAddr());
+            reset(email, lang, templId, cid, userid, request.getServerName(), senderIp);
 
             antiabuse.removeBad(email);
             ServletUtils.sendHtmlOK(response, "OK");
@@ -503,7 +508,7 @@ public class Guest {
         }
     }
 
-    protected void reset(String email, String lang, int templId, int cid, int userid, String host) throws OXException {
+    protected void reset(String email, String lang, int templId, int cid, int userid, String host, String senderIp) throws OXException {
         GuardKeyService keyService = Services.getService(GuardKeyService.class);
 
         boolean recoveryEnabled = keyService.isRecoveryEnabled(userid, cid);
@@ -517,7 +522,7 @@ public class Guest {
         JsonObject mail = mailCreatorService.getResetEmail(email, mailCreatorService.getFromAddress(email, email, userid, cid), newpass, lang, templId, host, userid, cid);
 
         GuardNotificationService guardNotificationService = Services.getService(GuardNotificationService.class);
-        guardNotificationService.send(mail);
+        guardNotificationService.send(mail, senderIp);
 
         keyService.resetPassword(email, newpass);
     }
