@@ -52,6 +52,7 @@ package com.openexchange.guard.servlets.keymanagement.actions;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import com.openexchange.exception.OXException;
+import com.openexchange.guard.common.servlets.utils.AntiAbuseUtils;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.keymanagement.commons.GuardKeys;
@@ -84,7 +85,7 @@ public class DeleteKeyPairAction extends GuardServletAction {
             if(keyToDelete.hasPrivateKey()) {
                 //Brute Force protect the key deletion if the key ring has a password protected private key.
                 final String password = ServletUtils.getStringParameter(request, Parameters.PARAM_PASSWORD, true);
-                AntiAbuseWrapper bruteForceProtection = getAntiAbuseWrapper(keyToDelete, password, userSession);
+                AntiAbuseWrapper bruteForceProtection = getAntiAbuseWrapper(keyToDelete, AntiAbuseUtils.getAllowParameters(request, userSession.getUserId(),  userSession.getContextId(), password));
                 bruteForceProtection.doAction(new AntiAbuseAction<Void>() {
 
                     @Override
