@@ -52,6 +52,7 @@ package com.openexchange.guard.servlets.keymanagement.actions;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import com.openexchange.exception.OXException;
+import com.openexchange.guard.common.servlets.utils.AntiAbuseUtils;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
 import com.openexchange.guard.exceptions.GuardAuthExceptionCodes;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
@@ -90,13 +91,13 @@ public class GetKeyAction extends GuardServletAction {
      * @return {@link GuardKeyInfoResponse}
      * @throws OXException if the user provided a bad password or the account is locked due.
      */
-    private GuardKeyInfoResponse createProtectedResponse(final HttpServletRequest request, final GuardUserSession userSession, final GuardKeys keys, final boolean omitPublicKey) throws OXException {
+    private GuardKeyInfoResponse createProtectedResponse(final HttpServletRequest request, final GuardUserSession userSession, final GuardKeys keys, final boolean omitPublicKey) throws Exception {
         final String password = ServletUtils.getStringParameter(request, Parameters.PARAM_PASSWORD, true);
-        AntiAbuseWrapper antiAbuseProtection = getAntiAbuseWrapper(keys, password, userSession);
+        AntiAbuseWrapper antiAbuseProtection = getAntiAbuseWrapper(keys, AntiAbuseUtils.getAllowParameters(request, userSession.getUserId(),  userSession.getContextId(), password));
         return antiAbuseProtection.doAction(new AntiAbuseAction<GuardKeyInfoResponse>() {
 
             @Override
-            public GuardKeyInfoResponse doAction() throws OXException {
+            public GuardKeyInfoResponse doAction() throws Exception {
                 return new GuardKeyInfoResponse(keys, password, omitPublicKey);
             }
         });
