@@ -52,6 +52,7 @@ package com.openexchange.guard.servlets.keymanagement.actions;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import com.openexchange.exception.OXException;
+import com.openexchange.guard.common.servlets.utils.AntiAbuseUtils;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.keymanagement.commons.GuardKeys;
@@ -87,7 +88,7 @@ public class RevokeKeyAction extends GuardServletAction {
         if (key != null) {
 
             //Revoke the key in a brute force protected way
-            AntiAbuseWrapper bruteForceProtection = getAntiAbuseWrapper(key, password, userSession);
+            AntiAbuseWrapper bruteForceProtection = getAntiAbuseWrapper(key, AntiAbuseUtils.getAllowParameters(request, userSession.getUserId(),  userSession.getContextId(), password));
             bruteForceProtection.doAction(new AntiAbuseAction<Void>() {
 
                 @Override
