@@ -61,10 +61,6 @@ import org.bouncycastle.openpgp.PGPSecretKeyRing;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.inputvalidation.EmailValidator;
-import com.openexchange.guard.keymanagement.commons.parsing.AsciiArmoredKeyParser;
-import com.openexchange.guard.keymanagement.commons.parsing.KeyParserResult;
-import com.openexchange.guard.keymanagement.commons.parsing.PGPPublicKeyRingFactory;
-import com.openexchange.guard.keymanagement.commons.parsing.PGPSecretKeyRingFactory;
 import com.openexchange.guard.keymanagement.services.KeyImportService;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.oxapi.Api;
@@ -72,6 +68,8 @@ import com.openexchange.guard.oxapi.OxCookie;
 import com.openexchange.guard.servlets.GuardServletAction;
 import com.openexchange.guard.servlets.authentication.GuardUserSession;
 import com.openexchange.guard.servlets.fileupload.FileUploadHandler;
+import com.openexchange.pgp.keys.parsing.KeyRingParserResult;
+import com.openexchange.pgp.keys.parsing.PGPKeyRingParser;
 
 /**
  * {@link UploadKeysAction} allows to upload custom, client created, public and private keys.
@@ -99,6 +97,7 @@ public class UploadKeysAction extends GuardServletAction {
         Collection<FileItem> items = fileUploadHandler.parseItems(request, MAX_KEY_FILE_UPLOAD_SIZE);
         String keyPassword = null;
         String newPassword = null;
+        PGPKeyRingParser keyParser = Services.getService(PGPKeyRingParser.class);
         if (items.size() > 0) {
             //Get actual Key data
             for (FileItem item : items) {
@@ -109,11 +108,13 @@ public class UploadKeysAction extends GuardServletAction {
                     newPassword = item.getString(StandardCharsets.UTF_8.displayName());
                 }
                 else{
-                    KeyParserResult parseResult = new AsciiArmoredKeyParser().parse(item.getInputStream());
-                    parsedSecretKeyRings = new ArrayList<PGPSecretKeyRing>();
-                    parsedSecretKeyRings.addAll(PGPSecretKeyRingFactory.create(parseResult));
-                    parsedPublicKeyRings = new ArrayList<PGPPublicKeyRing>();
-                    parsedPublicKeyRings.addAll(PGPPublicKeyRingFactory.create(parseResult));
+                    KeyRingParserResult parseResult = keyParser.parse(item.getInputStream());
+                    if(parseResult != null) {
+                        parsedSecretKeyRings = new ArrayList<PGPSecretKeyRing>();
+                        parsedSecretKeyRings.addAll(parseResult.toSecretKeyRings());
+                        parsedPublicKeyRings = new ArrayList<PGPPublicKeyRing>();
+                        parsedPublicKeyRings.addAll(parseResult.toPublicKeyRings());
+                    }
                 }
             }
         } else {
