@@ -52,17 +52,18 @@ package com.openexchange.guard.servlets.pgpcore;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import org.apache.commons.fileupload.FileItem;
-import com.google.gson.JsonObject;
+import org.json.JSONObject;
+
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.exceptions.GuardAuthExceptionCodes;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.pgpcore.services.PGPCryptoService;
 import com.openexchange.guard.pgpcore.services.TokenAuthenticationService;
-import com.openexchange.guard.pgpcore.services.UserIdentity;
 import com.openexchange.guard.servlets.GuardServletAction;
 import com.openexchange.guard.servlets.authentication.GuardUserSession;
 import com.openexchange.guard.servlets.fileupload.FileUploadHandler;
 import com.openexchange.guard.servlets.fileupload.JsonFileUploadHandler;
+import com.openexchange.guard.user.UserIdentity;
 import java.io.InputStream;
 import java.util.Collection;
 
@@ -91,7 +92,7 @@ public class DecryptAction extends GuardServletAction {
         Collection<FileItem> items = fileUploadHandler.parseItems(request);
         try (InputStream dataStream = fileUploadHandler.getFileItemStreamFrom(items, DATA_FIELD_NAME,true)){
 
-            JsonObject json = jsonFileUploadHandler.getJsonFrom(items, JSON_DATA_FIELD_NAME, true);
+            JSONObject json = jsonFileUploadHandler.getJsonFrom(items, JSON_DATA_FIELD_NAME, true);
             UserIdentity userIdentity = new UserIdentityJsonParser(Services.getService(TokenAuthenticationService.class), json).parse();
             if (userIdentity == null) {
                 throw GuardAuthExceptionCodes.BAD_PASSWORD.create();
