@@ -62,6 +62,9 @@ import org.apache.commons.fileupload.FileItemIterator;
 import org.apache.commons.fileupload.FileItemStream;
 import org.apache.commons.io.IOUtils;
 import org.apache.commons.io.output.DeferredFileOutputStream;
+import org.json.JSONArray;
+import org.json.JSONException;
+import org.json.JSONObject;
 import org.slf4j.LoggerFactory;
 import org.slf4j.Logger;
 import com.google.gson.JsonArray;
@@ -75,11 +78,11 @@ import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.pgpcore.services.PGPCryptoService;
 import com.openexchange.guard.pgpcore.services.TokenAuthenticationService;
-import com.openexchange.guard.pgpcore.services.UserIdentity;
 import com.openexchange.guard.servlets.GuardServletAction;
 import com.openexchange.guard.servlets.authentication.GuardUserSession;
 import com.openexchange.guard.servlets.fileupload.FileUploadHandler;
 import com.openexchange.guard.servlets.fileupload.JsonFileUploadHandler;
+import com.openexchange.guard.user.UserIdentity;
 
 /**
  * {@link EncryptAction}
@@ -94,6 +97,7 @@ public class EncryptAction extends GuardServletAction {
     private static final String JSON_DATA_FIELD_NAME = "json";
     private static final String DATA_FIELD_NAME = "data";
     private static final String OPTION_ARMORED = "armored";
+    private static final String RECIPIENT_ARRAY_NAME = "recipients";
 
     /**
      * Parses the recipient list from the given JSON object
@@ -101,14 +105,21 @@ public class EncryptAction extends GuardServletAction {
      * @param json the JSON object to parse the recipient list from
      * @return A list of recipients parsed from the given JSON object
      * @throws OXException
+     * @throws JSONException 
      */
-    private List<String> getRecipientFromJson(JsonObject json) throws OXException {
-        JsonArray recipients = JsonUtil.getArrayFromJson(json, "recipients", true);
-        ArrayList<String> ret = new ArrayList<>();
-        for (JsonElement recipient : recipients) {
-            ret.add(recipient.getAsString());
-        }
-        return ret;
+    private List<String> getRecipientFromJson(JSONObject json) throws OXException, JSONException {
+    	
+    	if(json.has(RECIPIENT_ARRAY_NAME)){
+    		JSONArray recipients = json.getJSONArray(RECIPIENT_ARRAY_NAME);
+	        ArrayList<String> ret = new ArrayList<>();
+	        for(int i = 0; i < recipients.length(); i++){
+	        	ret.add(recipients.getString(i));
+	        }
+	        return ret;
+    	}
+    	else{
+    		throw GuardCoreExceptionCodes.JSON_PARAMETER_MISSING.create(RECIPIENT_ARRAY_NAME);
+    	}
     }
 
     /*
@@ -119,7 +130,7 @@ public class EncryptAction extends GuardServletAction {
     @Override
     protected void doActionInternal(HttpServletRequest request, HttpServletResponse response, GuardUserSession userSession) throws Exception {
 
-        JsonObject json = null;
+        JSONObject json = null;
         InputStream dataStream = null;
         FileUploadHandler fileUploadHandler = new FileUploadHandler(Services.getService(GuardConfigurationService.class));
         JsonFileUploadHandler jsonFileUploadHandler = new JsonFileUploadHandler(fileUploadHandler);
