@@ -80,12 +80,23 @@ import com.openexchange.guard.util.RatifierUtil;
  */
 public class DecryptedMailResponseFactory {
 
-	// Send HTML/Text body through normalizer
-	private static String normalizePart (Part p) throws OXException, IOException, MessagingException {
-		String data = (String) p.getContent();
-		GuardRatifierService ratifier = Services.getService(GuardRatifierService.class);
-		return (ratifier.normalise(data));
-	}
+    // Send HTML/Text body through normalizer
+    private static String normalizePart (Part p) throws OXException, IOException, MessagingException {
+        String data = (String) p.getContent();
+        GuardRatifierService ratifier = Services.getService(GuardRatifierService.class);
+        return (ratifier.normalise(data));
+    }
+
+    public static void ParseStringBody (String content, JsonArray attachments) throws OXException {
+        JsonObject attachment = new JsonObject();
+        attachment.add("content_type", new JsonPrimitive("text/plain"));
+        GuardRatifierService ratifier = Services.getService(GuardRatifierService.class);
+        attachment.add("content", new JsonPrimitive(ratifier.normalise(content)));
+        attachment.add("disp", new JsonPrimitive("inline"));
+        attachment.add("size", new JsonPrimitive(content.length()));
+        attachment.add("id", new JsonPrimitive(1));
+        attachments.add(attachment);
+    }
 
     public static void ParseMultipart(Multipart mp, JsonArray attachments) throws MessagingException, IOException, OXException {
         JsonObject plain = null;
@@ -182,7 +193,7 @@ public class DecryptedMailResponseFactory {
             //Plain text message
             String content = (String) message.getContent();
             JsonObject attachment = new JsonObject();
-            attachment.addProperty("content_type", "text/plain");
+            attachment.addProperty("content_type", message.getContentType().contains("html") ? "text/html" : "text/plain");
             attachment.addProperty("content", content);
             attachment.addProperty("size", content.length());
             attachment.add("disp", new JsonPrimitive("inline"));
