@@ -100,10 +100,10 @@ public class ImportVCardAction extends GuardServletAction {
         GuardEMailDecryptionService decryptionService = new GuardEMailDecryptionServiceImpl();
         byte[] vcard = null;
         if (inline) {
-            PGPDecryptionResult decryptionResult = decryptionService.decryptInlineAttachment(cookie, session, userAgent, folder, emailid, Integer.parseInt(attachid), userid, cid, password);
+            PGPDecryptionResult decryptionResult = decryptionService.decryptInlineAttachment(cookie, session, userAgent, folder, emailid, Integer.parseInt(attachid), userid, cid, password, ServletUtils.getClientIP(request));
             vcard = IOUtils.toByteArray(decryptionResult.getInputStream());
         } else {
-            PGPDecryptionResult decryptionResult = decryptionService.decryptMimeAttachmentByName(cookie, session, userAgent, folder, emailid, filename, userid, cid, password);
+            PGPDecryptionResult decryptionResult = decryptionService.decryptMimeAttachmentByName(cookie, session, userAgent, folder, emailid, filename, userid, cid, password, ServletUtils.getClientIP(request));
             vcard = IOUtils.toByteArray(decryptionResult.getInputStream());
         }
 
