@@ -52,8 +52,14 @@ package com.openexchange.guard.servlets.pgpmail;
 import java.util.HashMap;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
+import com.openexchange.exception.OXException;
+import com.openexchange.guard.configuration.GuardConfigurationService;
+import com.openexchange.guard.configuration.GuardProperty;
+import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.servlets.AbstractGuardServlet;
+import com.openexchange.guard.servlets.GuardErrorResponseRenderer;
 import com.openexchange.guard.servlets.GuardServletAction;
+import com.openexchange.guard.servlets.authentication.BasicAuthServletAuthenticationHandler;
 import com.openexchange.guard.servlets.authentication.OXGuardSessionAuthenticationHandler;
 
 /**
@@ -75,15 +81,22 @@ public class PGPMailServlet extends AbstractGuardServlet {
     private static final String GET_IMPORT_VCARD_FROM_ATTACHMENT_ACTION_ = "importvcard";
     private static final String POST_GET_PGPMAIL_ACTION = "getmail";
     private static final String POST_GET_PGPMAIL_INLINE_ACTION = "getinline";
+
+    private static final String POST_PROCESS_INCOMING_MIME = "process_mime";
+    private static final String POST_VERIFY_MESSAGE = "verify";
+    private static final String POST_DECRYPT_MIME_MESSAGE = "decrypt";
+
     private final HashMap<String, GuardServletAction> getActions;
     private final HashMap<String, GuardServletAction> postActions;
 
     /**
      * Initializes a new {@link PGPMailServlet}.
+     * @throws OXException
      */
-    public PGPMailServlet() {
+    public PGPMailServlet() throws OXException {
 
         OXGuardSessionAuthenticationHandler userSessionAuthenticationHandler = new OXGuardSessionAuthenticationHandler();
+        BasicAuthServletAuthenticationHandler basicAuthAuthenticationHandler = createBasicAuthHandler();
 
         //GET
         getActions = new HashMap<String, GuardServletAction>();
@@ -100,6 +113,27 @@ public class PGPMailServlet extends AbstractGuardServlet {
         postActions = new HashMap<String, GuardServletAction>();
         postActions.put(POST_GET_PGPMAIL_ACTION, new GetPGPMailAction().setAuthenticationHandler(userSessionAuthenticationHandler));
         postActions.put(POST_GET_PGPMAIL_INLINE_ACTION, new GetPGPMailInlineAction().setAuthenticationHandler(userSessionAuthenticationHandler));
+        postActions.put(POST_PROCESS_INCOMING_MIME,
+            new MimeEmailAction()
+                .setAuthenticationHandler(basicAuthAuthenticationHandler)
+                .setErrorResponseRenderer(new GuardErrorResponseRenderer(HttpServletResponse.SC_INTERNAL_SERVER_ERROR)));
+        postActions.put(POST_DECRYPT_MIME_MESSAGE,
+            new DecryptMimeEmailAction()
+                .setAuthenticationHandler(basicAuthAuthenticationHandler)
+                .setErrorResponseRenderer(new GuardErrorResponseRenderer(HttpServletResponse.SC_INTERNAL_SERVER_ERROR)));
+        postActions.put(POST_VERIFY_MESSAGE,
+            new VerifyMimeEmailAction()
+                .setErrorResponseRenderer(new GuardErrorResponseRenderer(HttpServletResponse.SC_INTERNAL_SERVER_ERROR)));
+
+
+    }
+
+    private BasicAuthServletAuthenticationHandler createBasicAuthHandler() throws OXException {
+        //Protecting the servlet's actions with BASIC-AUTH
+        GuardConfigurationService configService = Services.getService(GuardConfigurationService.class);
+        String restApiUsername = configService.getProperty(GuardProperty.restApiUsername);
+        String restApiPassword = configService.getProperty(GuardProperty.restApiPassword);
+        return new BasicAuthServletAuthenticationHandler(restApiUsername, restApiPassword);
     }
 
     /* (non-Javadoc)
