@@ -30,28 +30,26 @@ public class DeletedKeyExposer {
      * @throws OXException
      */
     private URI buildGetExposedKeyUri(DeletedKey deletedKey) throws OXException {
+
         GuardConfigurationService configService = Services.getService(GuardConfigurationService.class);
-        //Reading the whole reader path from the configuration
-        String fullReaderPath = configService.getProperty(GuardProperty.externalReaderPath);
-        if (!fullReaderPath.contains("/")) {
-            throw GuardCoreExceptionCodes.CONFIGURATION_ERROR.create("externalReaderPath", "Missing \"/\"");
+
+        final String base = configService.getProperty(GuardProperty.externalEmailURL);
+        if(base.isEmpty()) {
+            throw GuardCoreExceptionCodes.CONFIGURATION_ERROR.create("externalEmailURL", "Missing");
         }
 
-        //extracting the host name
-        int firstSlashIndex = fullReaderPath.indexOf("/");
-        String hostName = fullReaderPath.substring(0, firstSlashIndex);
-        if (hostName.isEmpty()) {
-            throw GuardCoreExceptionCodes.CONFIGURATION_ERROR.create("externalReaderPath", "Missing hostname");
+        final String uiWebPath = configService.getProperty("com.openexchange.UIWebPath");
+        if(uiWebPath.isEmpty()) {
+            throw GuardCoreExceptionCodes.CONFIGURATION_ERROR.create("com.openexchange.UIWebPath", "Missing");
         }
 
-        //extracting the path
-        String readerPath = fullReaderPath.substring(firstSlashIndex);
-        if (hostName.isEmpty()) {
-            throw GuardCoreExceptionCodes.CONFIGURATION_ERROR.create("externalReaderPath", "Missing path");
-        }
+        String path = uiWebPath + "/api/oxguard/retrieve";
 
         String scheme = "http" + (configService.getBooleanProperty(GuardProperty.backendSSL) ? "s" : "");
-        URIBuilder uri = new URIBuilder().setScheme(scheme).setHost(hostName).setPath(readerPath).setParameter("action", "getKey").setParameter("userid", String.valueOf(deletedKey.getUserId())).setParameter("cid", String.valueOf(deletedKey.getCid())).setParameter("token", String.valueOf(deletedKey.getSalt()));
+        URIBuilder uri = new URIBuilder().setScheme(scheme).setHost(base).setPath(path).
+            setParameter("action", "getExposedKeys").
+            setParameter("userId", String.valueOf(deletedKey.getUserId())).
+            setParameter("contextId", String.valueOf(deletedKey.getCid()));
         try {
             return uri.build();
         } catch (URISyntaxException e) {
