@@ -5,11 +5,11 @@ import java.util.ArrayList;
 import java.util.List;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.email.storage.ogEmail.EmailStorage;
-import com.openexchange.guard.keys.dao.DeletedKey;
-import com.openexchange.guard.keys.dao.GuardKeys;
-import com.openexchange.guard.keys.storage.DeletedKeysStorage;
-import com.openexchange.guard.keys.storage.KeyTableStorage;
-import com.openexchange.guard.keys.storage.PGPKeysStorage;
+import com.openexchange.guard.keymanagement.commons.DeletedKey;
+import com.openexchange.guard.keymanagement.commons.GuardKeys;
+import com.openexchange.guard.keymanagement.storage.DeletedKeysStorage;
+import com.openexchange.guard.keymanagement.storage.KeyTableStorage;
+import com.openexchange.guard.keymanagement.storage.PGPKeysStorage;
 import com.openexchange.guard.osgi.Services;
 
 /**
@@ -61,7 +61,7 @@ public class UserDeleter {
     /**
      * Deletes all Guard PGP keys within a given context.
      * Keys are backed up in {@link DeletedKeysStorage} before deletion
-     * 
+     *
      * @param contextId the id of the context
      * @throws OXException due an error
      */
@@ -82,13 +82,13 @@ public class UserDeleter {
     /**
      * Deletes all Guard PGP keys related to a given user.
      * Keys are backed up in {@link DeletedKeysStorage} before deletion
-     * 
+     *
      * @param userId the user's id
      * @param contextId the context id
      * @throws OXException due an error
      */
     public void deleteWithBackup(int userId, int contextId) throws OXException {
-        
+
         KeyTableStorage keyTableStorage = Services.getService(KeyTableStorage.class);
         if (keyTableStorage.exists(userId, contextId, 0 /* not relevant */)) {
             List<GuardKeys> keys = keyTableStorage.getKeysForUser(userId, contextId);
@@ -103,7 +103,7 @@ public class UserDeleter {
     /**
      * Deletes all Guard PGP keys related to a given user without creating a backup.
      * For backing up keys before deletion see {@link #deleteWithBackup(int,int)}
-     * 
+     *
      * @param userId
      * @param contextId
      * @throws OXException
